import os
from os.path import basename, join
import random
import sys
import unittest
import glob
import config
import importlib
# To log while testing
import ibm_db
ibm_db.debug("log.txt")

_HTML_RUNNER = False

try:
    import HtmlTestRunner
    _HTML_RUNNER = True
except ImportError as e:
    print("HtmlTestRunner Package not found .. Running with normal unit test runs")

# Test runner for ibm_db. Normally one could use something like:
#
# Run all in the tests directory:
#   python -m unittest discover -v -s tests
#
# Run all tests matching specified pattern or specific test:
#   python -m unittest discover -v -s tests -p 'test_*FetchAssocSelect*.py'
#   python -m unittest discover -v -s tests -p test_006_ConnPassingOpts.py
#
# However, for running all the tests, we need to ensure that test_000_PrepareDb
# is run first to set up the database. Possibly this could be moved to a
# separate task which is run by itself prior to running any tests, which
# would simplify things a bit.

# Override standard test-loading behavior
def load_tests(loader, tests, pattern):
    suite = unittest.TestSuite()

    test_glob_default = "test_*.py"
    test_glob = os.environ.get("SINGLE_PYTHON_TEST", test_glob_default)
    # We need files of a given size for some of the test units, so create them
    # here.
    with open("ibm_db_tests/spook.png", "wb") as f:
        f.write(bytearray([random.getrandbits(8) for _ in range(0, 10291)]))
    with open("ibm_db_tests/pic1.jpg", "wb") as f:
        f.write(bytearray([random.getrandbits(8) for _ in range(0, 15398)]))

    files = glob.glob(join(config.test_dir, test_glob))
    tests = [ basename(_).replace('.py', '') for _ in files ]
    tests.sort()

    for test in tests:
        skip = (test.startswith('test_002') or \
                test.startswith('test_007') or \
                test.startswith('test_080') or \
                test.startswith('test_090') or \
                test.startswith('test_053') or \
                test.startswith('test_196') or \
                test.startswith('test_220') or \
                test.startswith('test_221') or \
                test.startswith('test_264') or \
                test.startswith('test_6792'))
        if test_glob != test_glob_default or not skip:
            mod = importlib.import_module(test)
            suite.addTest(mod.IbmDbTestCase(test))

    return suite

if __name__ == '__main__':
    sys.path.insert(0, config.test_dir)
    if(_HTML_RUNNER):
        unittest.main(testRunner=HtmlTestRunner.HTMLTestRunner(report_name='result',combine_reports=True))
    else:
        unittest.main(verbosity=3)



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_133_ExecuteLongInputParams(self):
        obj = IbmDbTestFunctions()
        obj.assert_expectf(self.run_test_133)

    def run_test_133(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        if (not conn):
            print("Connection failed.")
            return 0

        ibm_db.autocommit(conn, ibm_db.SQL_AUTOCOMMIT_OFF)

        print("Starting test ...")
        res = ''
        sql =  "INSERT INTO animals (id, breed, name, weight) VALUES (?, ?, ?, ?)"
        try:
            stmt = ibm_db.prepare(conn, sql)
            res = ibm_db.execute(stmt,(128, 'hacker of human and technological nature', 'Wez the ruler of all things PECL', 88.3))

            stmt = ibm_db.prepare(conn, "SELECT breed, name FROM animals WHERE id = ?")
            res = ibm_db.execute(stmt, (128,))
            row = ibm_db.fetch_assoc(stmt)

            for i in row:
                print(i)

            ibm_db.rollback(conn)
            print("Done")
        except:
            print("SQLSTATE: %s" % ibm_db.stmt_error(stmt))
            print("Message: %s" % ibm_db.stmt_errormsg(stmt))

        try:
            stmt = ibm_db.prepare(conn, "SELECT breed, name FROM animals WHERE id = ?")
            res = ibm_db.execute(stmt, (128,))
            row = ibm_db.fetch_assoc(stmt)
            if (row):
                for i in row:
                    print(i)
            print(res)
            print("SQLSTATE: %s" % ibm_db.stmt_error(stmt))
            print("Message: %s" % ibm_db.stmt_errormsg(stmt))
        except:
            print("An Exception is not expected")
            print("SQLSTATE: %s" % ibm_db.stmt_error(stmt))
            print("Message: %s" % ibm_db.stmt_errormsg(stmt))

        ibm_db.rollback(conn)
        print("Done")

#__END__
#__LUW_EXPECTED__
#Starting test ...
#
#SQLSTATE: 22001
#Message: [IBM][CLI Driver] CLI0109E  String data right truncation. SQLSTATE=22001 SQLCODE=-99999
#True
#SQLSTATE: 02000
#Message: [IBM][CLI Driver][DB2/%s] SQL0100W  No row was found for FETCH, UPDATE or DELETE; or the result of a query is an empty table.  SQLSTATE=02000 SQLCODE=100
#Done
#__ZOS_EXPECTED__
#Starting test ...
#
#SQLSTATE: 22001
#Message: [IBM][CLI Driver] CLI0109E  String data right truncation. SQLSTATE=22001 SQLCODE=-99999
#True
#SQLSTATE: 02000
#Message: [IBM][CLI Driver][DB2] SQL0100W  No row was found for FETCH, UPDATE or DELETE; or the result of a query is an empty table.  SQLSTATE=02000 SQLCODE=100
#Done
#__SYSTEMI_EXPECTED__
#Starting test ...
#
#SQLSTATE: 22001
#Message: [IBM][CLI Driver] CLI0109E  String data right truncation. SQLSTATE=22001 SQLCODE=-99999
#True
#SQLSTATE: 02000
#Message: [IBM][CLI Driver][AS] SQL0100W  No row was found for FETCH, UPDATE or DELETE; or the result of a query is an empty table.  SQLSTATE=02000 SQLCODE=100
#Done
#__IDS_EXPECTED__
#Starting test ...
#
#SQLSTATE: 22001
#Message: [IBM][CLI Driver][IDS%s] Value exceeds string column length. SQLCODE=-1279
#True
#SQLSTATE: 02000
#Message: [IBM][CLI Driver][IDS%s] SQL0100W  No row was found for FETCH, UPDATE or DELETE; or the result of a query is an empty table.  SQLSTATE=02000 SQLCODE=100
#Done
#__ZOS_ODBC_EXPECTED__
#Starting test ...
#
#SQLSTATE: 22001
#Message: {DB2 FOR OS/390}{ODBC DRIVER}  SQLSTATE=22001  ERRLOC=12:9:1 SQLCODE=-99999
#True
#SQLSTATE: 
#Message: 
#Done



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_unicodeTable(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_unicodeTable)

    def run_test_unicodeTable(self):
        try:
            connection = ibm_db.connect(config.database, config.user, config.password)
            print("=> Connected to Server ... SUCCESSFULL")
        except:
            print("=> Connection to server .... FAILED")
            print("Error Description = " + ibm_db.conn_errormsg())
            print("SQLSTATE = " + ibm_db.conn_error())
            return 0

        serverInfo = ibm_db.server_info(connection)

        if("IDS" in serverInfo.DBMS_NAME):
            print("No run for IDS")
            return 0

        print("=> Server Type = " + serverInfo.DBMS_NAME)

        print("=> Create table with unicode Column Name")

        table_create = "Create TABLE test_uni(\"åÅÕ\" int, \"ñéü\" int)"
        table_drop = "drop table test_uni"

        try:
            rc = ibm_db.exec_immediate(connection,table_create)
        except:
            rc = ibm_db.exec_immediate(connection,table_drop)
            rc = ibm_db.exec_immediate(connection,table_create)

        print("=> Table Created...")

        print("=> Getting field type of the table with unicode column")

        select = "select * from test_uni"

        rc = ibm_db.exec_immediate(connection,select)

        for i in range(0,ibm_db.num_fields(rc)):
            print("=> ROW : " + str(i) + "[" + str(ibm_db.field_type(rc,i)) + "]")
            print("=> COL NAME : " + str(i) + "[" + str(ibm_db.field_name(rc,i)) + "]")

        print("=> Insert data into table with unicode column")

        insert = "insert into test_uni(\"åÅÕ\",\"ñéü\") values(1,2)"

        rc = ibm_db.exec_immediate(connection,insert)

        print("=> Fetching data from table with unicode column")

        select = "select \"ñéü\" from test_uni"

        rc = ibm_db.exec_immediate(connection,select)
        row = ibm_db.fetch_tuple(rc)

        print("=> Using fetch_tuple")

        while row:
            print(row[0])
            row = ibm_db.fetch_tuple(rc)

        print("=> Using fetch_assoc")
        rc = ibm_db.exec_immediate(connection,select)
        row = ibm_db.fetch_assoc(rc)

        while row:
            print(row)
            row = ibm_db.fetch_assoc(rc)

        print("=> Create table with unicode character in table name")

        create2 = "create table \"ÆÈÊ\" (\"åÅÕ\" int, \"ñéü\" varchar(20))"
        drop2 = "drop table \"ÆÈÊ\""

        try:
            rc = ibm_db.exec_immediate(connection,create2)
        except:
            rc = ibm_db.exec_immediate(connection,drop2)
            rc = ibm_db.exec_immediate(connection,create2)

        print("=> Table created")

        print("=> Insert data into unicode named table")

        insert2 = "insert into \"ÆÈÊ\"(\"åÅÕ\",\"ñéü\") values(1,\'data1\')"

        rc = ibm_db.exec_immediate(connection,insert2)

        print("=> Getting field type of the unicode named table")

        select = "select * from \"ÆÈÊ\""

        rc = ibm_db.exec_immediate(connection,select)

        for i in range(0,ibm_db.num_fields(rc)):
            print("=> ROW : " + str(i) + "[" + str(ibm_db.field_type(rc,i)) + "]")
            print("=> COL NAME : " + str(i) + "[" + str(ibm_db.field_name(rc,i)) + "]")

        print("=> Fetching data from unicode named table")

        select = "select \"ñéü\" from \"ÆÈÊ\""

        rc = ibm_db.exec_immediate(connection,select)
        row = ibm_db.fetch_tuple(rc)

        print("=> Using Fetch Tuple")

        while row:
            print(row[0])
            row = ibm_db.fetch_tuple(rc)

        print("=> Using fetch_assoc")

        rc = ibm_db.exec_immediate(connection,select)
        row = ibm_db.fetch_assoc(rc)

        while row:
            print(row)
            row = ibm_db.fetch_assoc(rc)

#__END__
#__LUW_EXPECTED__
#=> Connected to Server ... SUCCESSFULL
#=> Server Type = DB2/LINUXX8664
#=> Create table with unicode Column Name
#=> Table Created...
#=> Getting field type of the table with unicode column
#=> ROW : 0[int]
#=> COL NAME : 0[åÅÕ]
#=> ROW : 1[int]
#=> COL NAME : 1[ñéü]
#=> Insert data into table with unicode column
#=> Fetching data from table with unicode column
#=> Using fetch_tuple
#2
#=> Using fetch_assoc
#{'ñéü': 2}
#=> Create table with unicode character in table name
#=> Table created
#=> Insert data into unicode named table
#=> Getting field type of the unicode named table
#=> ROW : 0[int]
#=> COL NAME : 0[åÅÕ]
#=> ROW : 1[string]
#=> COL NAME : 1[ñéü]
#=> Fetching data from unicode named table
#=> Using Fetch Tuple
#data1
#=> Using fetch_assoc
#{'ñéü': 'data1'}
#__ZOS_EXPECTED__
#=> Connected to Server ... SUCCESSFULL
#=> Server Type = DB2
#=> Create table with unicode Column Name
#=> Table Created...
#=> Getting field type of the table with unicode column
#=> ROW : 0[int]
#=> COL NAME : 0[åÅÕ]
#=> ROW : 1[int]
#=> COL NAME : 1[ñéü]
#=> Insert data into table with unicode column
#=> Fetching data from table with unicode column
#=> Using fetch_tuple
#2
#=> Using fetch_assoc
#{'ñéü': 2}
#=> Create table with unicode character in table name
#=> Table created
#=> Insert data into unicode named table
#=> Getting field type of the unicode named table
#=> ROW : 0[int]
#=> COL NAME : 0[åÅÕ]
#=> ROW : 1[string]
#=> COL NAME : 1[ñéü]
#=> Fetching data from unicode named table
#=> Using Fetch Tuple
#data1
#=> Using fetch_assoc
#{'ñéü': 'data1'}
#__SYSTEMI_EXPECTED__
#=> Connected to Server ... SUCCESSFULL
#=> Server Type = AS
#=> Create table with unicode Column Name
#=> Table Created...
#=> Getting field type of the table with unicode column
#=> ROW : 0[int]
#=> COL NAME : 0[åÅÕ]
#=> ROW : 1[int]
#=> COL NAME : 1[ñéü]
#=> Insert data into table with unicode column
#=> Fetching data from table with unicode column
#=> Using fetch_tuple
#2
#=> Using fetch_assoc
#{'ñéü': 2}
#=> Create table with unicode character in table name
#=> Table created
#=> Insert data into unicode named table
#=> Getting field type of the unicode named table
#=> ROW : 0[int]
#=> COL NAME : 0[åÅÕ]
#=> ROW : 1[string]
#=> COL NAME : 1[ñéü]
#=> Fetching data from unicode named table
#=> Using Fetch Tuple
#data1
#=> Using fetch_assoc
#{'ñéü': 'data1'}
#__IDS_EXPECTED__
#=> Connected to Server ... SUCCESSFULL
#No run for IDS
#__ZOS_ODBC_EXPECTED__
#=> Connected to Server ... SUCCESSFULL
#=> Server Type = DSN12015
#=> Create table with unicode Column Name
#=> Table Created...
#=> Getting field type of the table with unicode column
#=> ROW : 0[int]
#=> COL NAME : 0[åÅÕ]
#=> ROW : 1[int]
#=> COL NAME : 1[ñéü]
#=> Insert data into table with unicode column
#=> Fetching data from table with unicode column
#=> Using fetch_tuple
#2
#=> Using fetch_assoc
#{'ñéü': 2}
#=> Create table with unicode character in table name
#=> Table created
#=> Insert data into unicode named table
#=> Getting field type of the unicode named table
#=> ROW : 0[int]
#=> COL NAME : 0[åÅÕ]
#=> ROW : 1[string]
#=> COL NAME : 1[ñéü]
#=> Fetching data from unicode named table
#=> Using Fetch Tuple
#data1
#=> Using fetch_assoc
#{'ñéü': 'data1'}


#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_158_FetchAssocNestedSelects_02(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_158)

    def run_test_158(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        server = ibm_db.server_info( conn )
        if (server.DBMS_NAME[0:3] == 'IDS'):
            op = {ibm_db.ATTR_CASE: ibm_db.CASE_UPPER}
            ibm_db.set_option(conn, op, 1)

        result = ibm_db.exec_immediate(conn, "SELECT * FROM staff WHERE id < 50")

        output = ''
        row = ibm_db.fetch_assoc(result)
        while ( row ):
            output += str(row['ID']) + ', ' + row['NAME'] + ', ' + str(row['DEPT']) + ', ' + row['JOB'] + ', ' + str(row['YEARS']) + ', ' + str(row['SALARY']) + ', ' + str(row['COMM'])
            row = ibm_db.fetch_assoc(result)

        result2 = ibm_db.exec_immediate(conn,"SELECT * FROM department WHERE substr(deptno,1,1) in ('A','B','C','D','E')")
        row2 = ibm_db.fetch_assoc(result2)
        while ( row2 ):
            if (row2['MGRNO'] == None):
                row2['MGRNO'] = ''
            if (row2['LOCATION'] == None):
                row2['LOCATION'] = ''
            output += str(row2['DEPTNO']) + ', ' + row2['DEPTNAME'] + ', ' + str(row2['MGRNO']) + ', ' + row2['ADMRDEPT'] + ', ' + row2['LOCATION']
            row2 = ibm_db.fetch_assoc(result2)

        result3 = ibm_db.exec_immediate(conn,"SELECT * FROM employee WHERE lastname IN ('HAAS','THOMPSON', 'KWAN', 'GEYER', 'STERN', 'PULASKI', 'HENDERSON', 'SPENSER', 'LUCCHESSI', 'OCONNELL', 'QUINTANA', 'NICHOLLS', 'ADAMSON', 'PIANKA', 'YOSHIMURA', 'SCOUTTEN', 'WALKER', 'BROWN', 'JONES', 'LUTZ', 'JEFFERSON', 'MARINO', 'SMITH', 'JOHNSON', 'PEREZ', 'SCHNEIDER', 'PARKER', 'SMITH', 'SETRIGHT', 'MEHTA', 'LEE', 'GOUNOT')")
        row3 = ibm_db.fetch_tuple(result3)
        while ( row3 ):
            output += row3[0] + ', ' + row3[3] + ', ' + row3[5]
            row3=ibm_db.fetch_tuple(result3)
        print(output)

#__END__
#__LUW_EXPECTED__
#10, Sanders, 20, Mgr  , 7, 18357.50, None20, Pernal, 20, Sales, 8, 18171.25, 612.4530, Marenghi, 38, Mgr  , 5, 17506.75, None40, OBrien, 38, Sales, 6, 18006.00, 846.55A00, SPIFFY COMPUTER SERVICE DIV., 000010, A00, B01, PLANNING, 000020, A00, C01, INFORMATION CENTER, 000030, A00, D01, DEVELOPMENT CENTER, , A00, D11, MANUFACTURING SYSTEMS, 000060, D01, D21, ADMINISTRATION SYSTEMS, 000070, D01, E01, SUPPORT SERVICES, 000050, A00, E11, OPERATIONS, 000090, E01, E21, SOFTWARE SUPPORT, 000100, E01, 000010, HAAS, 3978000020, THOMPSON, 3476000030, KWAN, 4738000050, GEYER, 6789000060, STERN, 6423000070, PULASKI, 7831000090, HENDERSON, 5498000100, SPENSER, 0972000110, LUCCHESSI, 3490000120, OCONNELL, 2167000130, QUINTANA, 4578000140, NICHOLLS, 1793000150, ADAMSON, 4510000160, PIANKA, 3782000170, YOSHIMURA, 2890000180, SCOUTTEN, 1682000190, WALKER, 2986000200, BROWN, 4501000210, JONES, 0942000220, LUTZ, 0672000230, JEFFERSON, 2094000240, MARINO, 3780000250, SMITH, 0961000260, JOHNSON, 8953000270, PEREZ, 9001000280, SCHNEIDER, 8997000290, PARKER, 4502000300, SMITH, 2095000310, SETRIGHT, 3332000320, MEHTA, 9990000330, LEE, 2103000340, GOUNOT, 5698
#__ZOS_EXPECTED__
#10, Sanders, 20, Mgr  , 7, 18357.50, None20, Pernal, 20, Sales, 8, 18171.25, 612.4530, Marenghi, 38, Mgr  , 5, 17506.75, None40, OBrien, 38, Sales, 6, 18006.00, 846.55A00, SPIFFY COMPUTER SERVICE DIV., 000010, A00, B01, PLANNING, 000020, A00, C01, INFORMATION CENTER, 000030, A00, D01, DEVELOPMENT CENTER, , A00, D11, MANUFACTURING SYSTEMS, 000060, D01, D21, ADMINISTRATION SYSTEMS, 000070, D01, E01, SUPPORT SERVICES, 000050, A00, E11, OPERATIONS, 000090, E01, E21, SOFTWARE SUPPORT, 000100, E01, 000010, HAAS, 3978000020, THOMPSON, 3476000030, KWAN, 4738000050, GEYER, 6789000060, STERN, 6423000070, PULASKI, 7831000090, HENDERSON, 5498000100, SPENSER, 0972000110, LUCCHESSI, 3490000120, OCONNELL, 2167000130, QUINTANA, 4578000140, NICHOLLS, 1793000150, ADAMSON, 4510000160, PIANKA, 3782000170, YOSHIMURA, 2890000180, SCOUTTEN, 1682000190, WALKER, 2986000200, BROWN, 4501000210, JONES, 0942000220, LUTZ, 0672000230, JEFFERSON, 2094000240, MARINO, 3780000250, SMITH, 0961000260, JOHNSON, 8953000270, PEREZ, 9001000280, SCHNEIDER, 8997000290, PARKER, 4502000300, SMITH, 2095000310, SETRIGHT, 3332000320, MEHTA, 9990000330, LEE, 2103000340, GOUNOT, 5698
#__SYSTEMI_EXPECTED__
#10, Sanders, 20, Mgr  , 7, 18357.50, None20, Pernal, 20, Sales, 8, 18171.25, 612.4530, Marenghi, 38, Mgr  , 5, 17506.75, None40, OBrien, 38, Sales, 6, 18006.00, 846.55A00, SPIFFY COMPUTER SERVICE DIV., 000010, A00, B01, PLANNING, 000020, A00, C01, INFORMATION CENTER, 000030, A00, D01, DEVELOPMENT CENTER, , A00, D11, MANUFACTURING SYSTEMS, 000060, D01, D21, ADMINISTRATION SYSTEMS, 000070, D01, E01, SUPPORT SERVICES, 000050, A00, E11, OPERATIONS, 000090, E01, E21, SOFTWARE SUPPORT, 000100, E01, 000010, HAAS, 3978000020, THOMPSON, 3476000030, KWAN, 4738000050, GEYER, 6789000060, STERN, 6423000070, PULASKI, 7831000090, HENDERSON, 5498000100, SPENSER, 0972000110, LUCCHESSI, 3490000120, OCONNELL, 2167000130, QUINTANA, 4578000140, NICHOLLS, 1793000150, ADAMSON, 4510000160, PIANKA, 3782000170, YOSHIMURA, 2890000180, SCOUTTEN, 1682000190, WALKER, 2986000200, BROWN, 4501000210, JONES, 0942000220, LUTZ, 0672000230, JEFFERSON, 2094000240, MARINO, 3780000250, SMITH, 0961000260, JOHNSON, 8953000270, PEREZ, 9001000280, SCHNEIDER, 8997000290, PARKER, 4502000300, SMITH, 2095000310, SETRIGHT, 3332000320, MEHTA, 9990000330, LEE, 2103000340, GOUNOT, 5698
#__IDS_EXPECTED__
#10, Sanders, 20, Mgr  , 7, 18357.50, None20, Pernal, 20, Sales, 8, 18171.25, 612.4530, Marenghi, 38, Mgr  , 5, 17506.75, None40, OBrien, 38, Sales, 6, 18006.00, 846.55A00, SPIFFY COMPUTER SERVICE DIV., 000010, A00, B01, PLANNING, 000020, A00, C01, INFORMATION CENTER, 000030, A00, D01, DEVELOPMENT CENTER, , A00, D11, MANUFACTURING SYSTEMS, 000060, D01, D21, ADMINISTRATION SYSTEMS, 000070, D01, E01, SUPPORT SERVICES, 000050, A00, E11, OPERATIONS, 000090, E01, E21, SOFTWARE SUPPORT, 000100, E01, 000010, HAAS, 3978000020, THOMPSON, 3476000030, KWAN, 4738000050, GEYER, 6789000060, STERN, 6423000070, PULASKI, 7831000090, HENDERSON, 5498000100, SPENSER, 0972000110, LUCCHESSI, 3490000120, OCONNELL, 2167000130, QUINTANA, 4578000140, NICHOLLS, 1793000150, ADAMSON, 4510000160, PIANKA, 3782000170, YOSHIMURA, 2890000180, SCOUTTEN, 1682000190, WALKER, 2986000200, BROWN, 4501000210, JONES, 0942000220, LUTZ, 0672000230, JEFFERSON, 2094000240, MARINO, 3780000250, SMITH, 0961000260, JOHNSON, 8953000270, PEREZ, 9001000280, SCHNEIDER, 8997000290, PARKER, 4502000300, SMITH, 2095000310, SETRIGHT, 3332000320, MEHTA, 9990000330, LEE, 2103000340, GOUNOT, 5698



#
#    Licensed Materials - Property of IBM
#
#    (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import os
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):
    @unittest.skipIf((os.environ.get("CI", False)) or (sys.platform == 'zos'), "Test fails in CI")
    # Throws exception:
    # Exception: [IBM][CLI Driver] SQL30082N  Security processing failed
    # with reason "24" ("USERNAME AND/OR PASSWORD INVALID").  SQLSTATE=08001
    # SQLCODE=-30082
    def test_trusted_context_connect(self):
        obj = IbmDbTestFunctions()
        obj.assert_expectf(self.run_test_trusted_context_connect)

    def run_test_trusted_context_connect(self):
        # if the Db2-server cannot resolve the remote-client hostname(where testcase runs), then use config.py tc_appserver_address to give IP-address
        # and use that IP-address in the trusted-context definition, to allow operation remotely from the Db2-server.

        if ( sys.platform == 'win32'):  # on ms-windows get hostname from env to avoid importing other modules
            this_hostname = os.environ['COMPUTERNAME']
        else:
            this_hostname = os.uname()[1]  # get local non-windows hostname

        if config.tc_appserver_address:
            if config.tc_appserver_address != '':
                this_hostname = config.tc_appserver_address # in case Db2-server cannot resolve remote-client hostname
 
        
        sql_drop_role = "DROP ROLE role_01"
        sql_create_role = "CREATE ROLE role_01"

        sql_drop_trusted_context = "DROP TRUSTED CONTEXT ctx"

        sql_create_trusted_context = "CREATE TRUSTED CONTEXT ctx BASED UPON CONNECTION USING SYSTEM AUTHID "
        sql_create_trusted_context += config.auth_user
        sql_create_trusted_context += " ATTRIBUTES (ADDRESS '"
        sql_create_trusted_context += this_hostname
        sql_create_trusted_context += "') DEFAULT ROLE role_01 ENABLE WITH USE FOR "
        sql_create_trusted_context += config.tc_user

        sql_drop_table = "DROP TABLE trusted_table"
        sql_create_table = "CREATE TABLE trusted_table (i1 int, i2 int)"

        sql_select = "SELECT * FROM trusted_table"

        # Setting up database.
        conn = ibm_db.connect(config.database, config.user, config.password)
        if conn:
            sql_grant_permission = "GRANT INSERT ON TABLE trusted_table TO ROLE role_01"
            sql_create_trusted_context_01 = sql_create_trusted_context + " WITH AUTHENTICATION"
            try:
                result = ibm_db.exec_immediate(conn, sql_drop_trusted_context)
            except:
                pass
            try:
                result = ibm_db.exec_immediate(conn, sql_drop_table)
            except:
                pass
            try:
                result = ibm_db.exec_immediate(conn, sql_drop_role)
            except:
                pass
            try:
                result = ibm_db.exec_immediate(conn, sql_create_role)
            except:
                pass
            try:
                result = ibm_db.exec_immediate(conn, sql_create_table)
            except:
                pass
            try:
                result = ibm_db.exec_immediate(conn, sql_grant_permission)
            except:
                pass
            try:
                result = ibm_db.exec_immediate(conn, sql_create_trusted_context_01)
            except:
                pass

            # Populate the trusted_table
            values = (\
                (10, 20),\
                (20, 40),\
            )
            sql_insert = 'INSERT INTO trusted_table (i1, i2) VALUES (?, ?)'
            stmt = ibm_db.prepare(conn, sql_insert)
            if stmt:
                for value in values:
                    result = ibm_db.execute(stmt, value)
            ibm_db.close(conn)
        else:
            print("Connection failed.")

        options = {ibm_db.SQL_ATTR_USE_TRUSTED_CONTEXT: ibm_db.SQL_TRUE}
        tc_options = {
            ibm_db.SQL_ATTR_TRUSTED_CONTEXT_USERID: config.tc_user,
            ibm_db.SQL_ATTR_TRUSTED_CONTEXT_PASSWORD: config.tc_pass
        }
        tc_all_options = {
            ibm_db.SQL_ATTR_USE_TRUSTED_CONTEXT: ibm_db.SQL_TRUE,
            ibm_db.SQL_ATTR_TRUSTED_CONTEXT_USERID: config.tc_user,
            ibm_db.SQL_ATTR_TRUSTED_CONTEXT_PASSWORD: config.tc_pass
        }
        dsn = "DATABASE=%s;HOSTNAME=%s;PORT=%d;PROTOCOL=TCPIP;UID=%s;PWD=%s;" % (config.database, config.hostname, config.port, config.auth_user, config.auth_pass)

        # Makeing normal connection and playing with it.
        tc_conn = ibm_db.connect(dsn, "", "")
        if tc_conn:
            print("Normal connection established.")
            result = ibm_db.set_option(tc_conn, tc_options, 1)
            print(ibm_db.conn_errormsg(tc_conn))
            ibm_db.close(tc_conn)

        tc_conn = ibm_db.connect(dsn, "", "")
        if tc_conn:
            print("Normal connection established.")
            result = ibm_db.set_option(tc_conn, tc_all_options, 1)
            print(ibm_db.conn_errormsg(tc_conn))
            ibm_db.close(tc_conn)

        tc_conn = ibm_db.connect(dsn, "", "", tc_all_options)
        if tc_conn:
            val = ibm_db.get_option(tc_conn, ibm_db.SQL_ATTR_USE_TRUSTED_CONTEXT, 1)
            if val:
                print("Trusted connection succeeded.")
                get_tc_user = ibm_db.get_option(tc_conn, ibm_db.SQL_ATTR_TRUSTED_CONTEXT_USERID, 1)
                if config.tc_user != get_tc_user:
                    print("But trusted user is not switched.")
        ibm_db.close(tc_conn)

        # Making trusted connection and performing normal operations.
        tc_conn = ibm_db.connect(dsn, "", "", options)
        if tc_conn:
            print("Trusted connection succeeded.")
            val = ibm_db.get_option(tc_conn, ibm_db.SQL_ATTR_USE_TRUSTED_CONTEXT, 1)
            if val:
                userBefore = ibm_db.get_option(tc_conn, ibm_db.SQL_ATTR_TRUSTED_CONTEXT_USERID, 1)
                ibm_db.set_option(tc_conn, tc_options, 1)
                userAfter = ibm_db.get_option(tc_conn, ibm_db.SQL_ATTR_TRUSTED_CONTEXT_USERID, 1)
                if userBefore != userAfter:
                    print("User has been switched.")

                    # Inserting into table using trusted_user.
                    sql_insert = "INSERT INTO " + config.user + ".trusted_table (i1, i2) VALUES (?, ?)"
                    stmt = ibm_db.prepare(tc_conn, sql_insert)
                    result = ibm_db.execute(stmt, (300, 500))

                    # Updating table using trusted_user.
                    sql_update = "UPDATE " + config.user + ".trusted_table set i1 = 400 WHERE i2 = 500"
                    try:
                        stmt = ibm_db.exec_immediate(tc_conn, sql_update)
                    except:
                        print(ibm_db.stmt_errormsg())

            ibm_db.close(tc_conn)
        else:
            print("Trusted connection failed.")

        # Making trusted connection and switching to fake user.
        tc_conn = ibm_db.connect(dsn, "", "", options)

        if tc_conn:
            val = ibm_db.get_option(tc_conn, ibm_db.SQL_ATTR_USE_TRUSTED_CONTEXT, 1)
            if val:
                print("Trusted connection succeeded.")
                ibm_db.set_option(tc_conn, {ibm_db.SQL_ATTR_TRUSTED_CONTEXT_USERID: "fakeuser", ibm_db.SQL_ATTR_TRUSTED_CONTEXT_PASSWORD: "fakepassword"}, 1)

                sql_update = "UPDATE " + config.user + ".trusted_table set i1 = 400 WHERE i2 = 500"
                try:
                    stmt = ibm_db.exec_immediate(tc_conn, sql_update)
                except:
                    print(ibm_db.stmt_errormsg())
            ibm_db.close(tc_conn)
        else:
            print("Connection failed.")

        # Making trusted connection and passing password first then user while switching.
        tc_conn = ibm_db.connect(dsn, "", "", options)
        tc_options_reversed = {ibm_db.SQL_ATTR_TRUSTED_CONTEXT_PASSWORD: config.tc_pass, ibm_db.SQL_ATTR_TRUSTED_CONTEXT_USERID: config.tc_user}

        if tc_conn:
            val = ibm_db.get_option(tc_conn, ibm_db.SQL_ATTR_USE_TRUSTED_CONTEXT, 1)
            if val:
                print("Trusted connection succeeded.")
                userBefore = ibm_db.get_option(tc_conn, ibm_db.SQL_ATTR_TRUSTED_CONTEXT_USERID, 1)
                ibm_db.set_option(tc_conn, tc_options_reversed, 1)
                userAfter = ibm_db.get_option(tc_conn, ibm_db.SQL_ATTR_TRUSTED_CONTEXT_USERID, 1)
                if userBefore != userAfter:
                    print("User has been switched.")
            ibm_db.close(tc_conn)
        else:
            print("Connection failed.")

        # Making trusted connection and passing password first then user while switching.
        tc_conn = ibm_db.connect(dsn, "", "", options)
        tc_user_options = {ibm_db.SQL_ATTR_TRUSTED_CONTEXT_USERID: config.tc_user}
        tc_pass_options = {ibm_db.SQL_ATTR_TRUSTED_CONTEXT_PASSWORD: config.tc_pass}

        if tc_conn:
            print("Trusted connection succeeded.")
            val = ibm_db.get_option(tc_conn, ibm_db.SQL_ATTR_USE_TRUSTED_CONTEXT, 1)
            if val:
                userBefore = ibm_db.get_option(tc_conn, ibm_db.SQL_ATTR_TRUSTED_CONTEXT_USERID, 1)
                try:
                    ibm_db.set_option(tc_conn, tc_pass_options, 1)
                except:
                    print(ibm_db.conn_errormsg(tc_conn))
            ibm_db.close(tc_conn)
        else:
            print("Connection failed.")


        # Making trusted connection and passing only user while switching when both user and password are required.
        tc_conn = ibm_db.connect(dsn, "", "", options)

        if tc_conn:
            print("Trusted connection succeeded.")
            val = ibm_db.get_option(tc_conn, ibm_db.SQL_ATTR_USE_TRUSTED_CONTEXT, 1)
            if val:
                ibm_db.set_option(tc_conn, tc_user_options, 1)

                sql_update = "UPDATE " + config.user + ".trusted_table set i1 = 400 WHERE i2 = 500"
                try:
                    stmt = ibm_db.exec_immediate(tc_conn, sql_update)
                except:
                    print(ibm_db.stmt_errormsg())
            ibm_db.close(tc_conn)
        else:
            print("Connection failed.")


        # Make a connection
        conn = ibm_db.connect(config.database, config.user, config.password)

        if conn:
            # Dropping the trusted context, in case it exists
            try:
                result = ibm_db.exec_immediate(conn, sql_drop_trusted_context)
            except:
                pass

            # Dropping Role.
            try:
                result = ibm_db.exec_immediate(conn, sql_drop_role)
            except:
                pass

            # Creating Role.
            try:
                result = ibm_db.exec_immediate(conn, sql_create_role)
            except:
                pass

            # Granting permissions to role.
            try:
                sql_grant_permission = "GRANT UPDATE ON TABLE trusted_table TO ROLE role_01"
                result = ibm_db.exec_immediate(conn, sql_grant_permission)
            except:
                pass

            # Creating trusted context
            try:
                sql_create_trusted_context_01 = sql_create_trusted_context + " WITHOUT AUTHENTICATION"
                result = ibm_db.exec_immediate(conn, sql_create_trusted_context_01)
            except:
                pass

            # Closing connection
            ibm_db.close(conn)
        else:
            print("Connection failed.")

        # Making trusted connection
        tc_conn = ibm_db.connect(dsn, "", "", options)
        if tc_conn:
            print("Trusted connection succeeded.")
            val = ibm_db.get_option(tc_conn, ibm_db.SQL_ATTR_USE_TRUSTED_CONTEXT, 1)
            if val:
                userBefore = ibm_db.get_option(tc_conn, ibm_db.SQL_ATTR_TRUSTED_CONTEXT_USERID, 1)
                ibm_db.set_option(tc_conn, tc_user_options, 1)
                userAfter = ibm_db.get_option(tc_conn, ibm_db.SQL_ATTR_TRUSTED_CONTEXT_USERID, 1)
                if userBefore != userAfter:
                    print("User has been switched.")

                    # Inserting into table using trusted_user.
                    sql_insert = "INSERT INTO " + config.user + ".trusted_table (i1, i2) VALUES (300, 500)"
                    try:
                        stmt = ibm_db.exec_immediate(tc_conn, sql_insert)
                    except:
                        print(ibm_db.stmt_errormsg())

                    # Updating table using trusted_user.
                    sql_update = "UPDATE " + config.user + ".trusted_table set i1 = 400 WHERE i2 = 20"
                    stmt = ibm_db.exec_immediate(tc_conn, sql_update)
            ibm_db.close(tc_conn)
        else:
            print("Connection failed.")

        # Cleaning up database.
        conn = ibm_db.connect(config.database, config.user, config.password)

        if conn:
            print("Connection succeeded.")

            try:
                result = ibm_db.exec_immediate(conn, sql_drop_trusted_context)
            except:
                pass
            try:
                result = ibm_db.exec_immediate(conn, sql_drop_table)
            except:
                pass
            try:
                result = ibm_db.exec_immediate(conn, sql_drop_role)
            except:
                pass
            ibm_db.close(conn)
        else:
            print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#Normal connection established.
#[%s][%s] CLI0197E  A trusted context is not enabled on this connection. Invalid attribute value. SQLSTATE=HY010 SQLCODE=-99999
#Normal connection established.[%s][%s] CLI0197E  A trusted context is not enabled on this connection. Invalid attribute value. SQLSTATE=HY010 SQLCODE=-99999
#Trusted connection succeeded.
#But trusted user is not switched.
#Trusted connection succeeded.
#User has been switched.
#[%s][%s][%s] SQL0551N  The statement failed because the authorization ID does not have the required authorization or privilege to perform the operation.  Authorization ID: "%s".  Operation: "UPDATE". Object: "%s.TRUSTED_TABLE".  SQLSTATE=42501 SQLCODE=-551
#Trusted connection succeeded.
#[%s][%s][%s] SQL30082N  Security processing failed with reason "24" ("USERNAME AND/OR PASSWORD INVALID").  SQLSTATE=08001 SQLCODE=-30082
#Trusted connection succeeded.
#User has been switched.
#Trusted connection succeeded.
#Trusted connection succeeded.
#[%s][%s][%s] SQL20361N  The switch user request using authorization ID "%s" within trusted context "CTX" failed with reason code "2".  SQLSTATE=42517 SQLCODE=-20361
#Trusted connection succeeded.
#User has been switched.
#[%s][%s][%s] SQL0551N  The statement failed because the authorization ID does not have the required authorization or privilege to perform the operation.  Authorization ID: "%s".  Operation: "INSERT". Object: "%s.TRUSTED_TABLE".  SQLSTATE=42501 SQLCODE=-551
#Connection succeeded.
#__ZOS_EXPECTED__
#Normal connection established.
#[%s][%s] CLI0197E  A trusted context is not enabled on this connection. Invalid attribute value. SQLSTATE=HY010 SQLCODE=-99999
#Normal connection established.[%s][%s] CLI0197E  A trusted context is not enabled on this connection. Invalid attribute value. SQLSTATE=HY010 SQLCODE=-99999
#Trusted connection succeeded.
#But trusted user is not switched.
#Trusted connection succeeded.
#User has been switched.
#[%s][%s][%s] SQL0551N  The statement failed because the authorization ID does not have the required authorization or privilege to perform the operation.  Authorization ID: "%s".  Operation: "UPDATE". Object: "%s.TRUSTED_TABLE".  SQLSTATE=42501 SQLCODE=-551
#Trusted connection succeeded.
#[%s][%s][%s] SQL30082N  Security processing failed with reason "24" ("USERNAME AND/OR PASSWORD INVALID").  SQLSTATE=08001 SQLCODE=-30082
#Trusted connection succeeded.
#User has been switched.
#Trusted connection succeeded.
#Trusted connection succeeded.
#[%s][%s][%s] SQL20361N  The switch user request using authorization ID "%s" within trusted context "CTX" failed with reason code "2".  SQLSTATE=42517 SQLCODE=-20361
#Trusted connection succeeded.
#User has been switched.
#[%s][%s][%s] SQL0551N  The statement failed because the authorization ID does not have the required authorization or privilege to perform the operation.  Authorization ID: "%s".  Operation: "INSERT". Object: "%s.TRUSTED_TABLE".  SQLSTATE=42501 SQLCODE=-551
#Connection succeeded.
#__SYSTEMI_EXPECTED__
#Normal connection established.
#[%s][%s] CLI0197E  A trusted context is not enabled on this connection. Invalid attribute value. SQLSTATE=HY010 SQLCODE=-99999
#Normal connection established.[%s][%s] CLI0197E  A trusted context is not enabled on this connection. Invalid attribute value. SQLSTATE=HY010 SQLCODE=-99999
#Trusted connection succeeded.
#But trusted user is not switched.
#Trusted connection succeeded.
#User has been switched.
#[%s][%s][%s] SQL0551N  The statement failed because the authorization ID does not have the required authorization or privilege to perform the operation.  Authorization ID: "%s".  Operation: "UPDATE". Object: "%s.TRUSTED_TABLE".  SQLSTATE=42501 SQLCODE=-551
#Trusted connection succeeded.
#[%s][%s][%s] SQL30082N  Security processing failed with reason "24" ("USERNAME AND/OR PASSWORD INVALID").  SQLSTATE=08001 SQLCODE=-30082
#Trusted connection succeeded.
#User has been switched.
#Trusted connection succeeded.
#Trusted connection succeeded.
#[%s][%s][%s] SQL20361N  The switch user request using authorization ID "%s" within trusted context "CTX" failed with reason code "2".  SQLSTATE=42517 SQLCODE=-20361
#Trusted connection succeeded.
#User has been switched.
#[%s][%s][%s] SQL0551N  The statement failed because the authorization ID does not have the required authorization or privilege to perform the operation.  Authorization ID: "%s".  Operation: "INSERT". Object: "%s.TRUSTED_TABLE".  SQLSTATE=42501 SQLCODE=-551
#Connection succeeded.
#__IDS_EXPECTED__
#Normal connection established.
#[%s][%s] CLI0197E  A trusted context is not enabled on this connection. Invalid attribute value. SQLSTATE=HY010 SQLCODE=-99999
#Normal connection established.[%s][%s] CLI0197E  A trusted context is not enabled on this connection. Invalid attribute value. SQLSTATE=HY010 SQLCODE=-99999
#Trusted connection succeeded.
#But trusted user is not switched.
#Trusted connection succeeded.
#User has been switched.
#[%s][%s][%s] SQL0551N  The statement failed because the authorization ID does not have the required authorization or privilege to perform the operation.  Authorization ID: "%s".  Operation: "UPDATE". Object: "%s.TRUSTED_TABLE".  SQLSTATE=42501 SQLCODE=-551
#Trusted connection succeeded.
#[%s][%s][%s] SQL30082N  Security processing failed with reason "24" ("USERNAME AND/OR PASSWORD INVALID").  SQLSTATE=08001 SQLCODE=-30082
#Trusted connection succeeded.
#User has been switched.
#Trusted connection succeeded.
#Trusted connection succeeded.
#[%s][%s][%s] SQL20361N  The switch user request using authorization ID "%s" within trusted context "CTX" failed with reason code "2".  SQLSTATE=42517 SQLCODE=-20361
#Trusted connection succeeded.
#User has been switched.
#[%s][%s][%s] SQL0551N  The statement failed because the authorization ID does not have the required authorization or privilege to perform the operation.  Authorization ID: "%s".  Operation: "INSERT". Object: "%s.TRUSTED_TABLE".  SQLSTATE=42501 SQLCODE=-551
#Connection succeeded.



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#
# NOTE: IDS requires that you pass the schema name (cannot pass nil)
#
# NOTE: IDS will not return any rows from column_privileges unless
#       there have been privileges granted to another user other
#       then the user that is running the script.  This test assumes
#       that no other user has been granted permission and therefore
#       will return no rows.

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_023_ColumnPrivileges(self):
        obj = IbmDbTestFunctions()
        obj.assert_expectf(self.run_test_023)

    def run_test_023(self):
        conn = ibm_db.connect(config.database, config.user, config.password)
        server = ibm_db.server_info( conn )

        if (conn != 0):
            if (server.DBMS_NAME[0:3] == 'IDS'):
                stmt = ibm_db.column_privileges(conn, None, config.user, 'animals')
            elif (sys.platform == 'zos'):
                stmt = ibm_db.column_privileges(conn, None, config.user, 'ANIMALS')
            else:
                stmt = ibm_db.column_privileges(conn, None, None, 'ANIMALS')
            row = ibm_db.fetch_tuple(stmt)
            if row:
                print(row[0])
                print(row[1])
                print(row[2])
                print(row[3])
                print(row[4])
                print(row[5])
                print(row[6])
                print(row[7])
            ibm_db.close(conn)
        else:
            print(ibm_db.conn_errormsg())
            print("Connection failed\n\n")

#__END__
#__LUW_EXPECTED__
#%s
#%s
#ANIMALS
#BREED
#SYSIBM
#%s
#%s
#YES
#__ZOS_EXPECTED__
#None
#%s
#ANIMALS
#BREED
#%s
#%s
#%s
#YES
#__SYSTEMI_EXPECTED__
#%s
#%s
#ANIMALS
#BREED
#None
#%s
#%s
#YES
#__IDS_EXPECTED__



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_142_BindParamSelectStmtMultipleParams_02(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_142)

    def run_test_142(self):
        sql = "SELECT id, breed, name, weight FROM animals WHERE weight < ? AND weight > ?"

        conn = ibm_db.connect(config.database, config.user, config.password)

        if conn:
            stmt = ibm_db.prepare(conn, sql)

            weight = 200.05
            mass = 2.0

            ibm_db.bind_param(stmt, 1, weight, ibm_db.SQL_PARAM_INPUT)
            ibm_db.bind_param(stmt, 2, mass, ibm_db.SQL_PARAM_INPUT)

            result = ibm_db.execute(stmt)
            if ( result ):
                row = ibm_db.fetch_tuple(stmt)
                while ( row ):
                    #row.each { |child| print child }
                    for i in row:
                        print(i)
                    row = ibm_db.fetch_tuple(stmt)
            ibm_db.close(conn)
        else:
            print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#0
#cat
#Pook            
#3.20
#1
#dog
#Peaches         
#12.30
#5
#goat
#Rickety Ride    
#9.70
#6
#llama
#Sweater         
#150.00
#__ZOS_EXPECTED__
#0
#cat
#Pook            
#3.20
#1
#dog
#Peaches         
#12.30
#5
#goat
#Rickety Ride    
#9.70
#6
#llama
#Sweater         
#150.00
#__SYSTEMI_EXPECTED__
#0
#cat
#Pook            
#3.20
#1
#dog
#Peaches         
#12.30
#5
#goat
#Rickety Ride    
#9.70
#6
#llama
#Sweater         
#150.00
#__IDS_EXPECTED__
#0
#cat
#Pook            
#3.20
#1
#dog
#Peaches         
#12.30
#5
#goat
#Rickety Ride    
#9.70
#6
#llama
#Sweater         
#150.00



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_stmt_get_sqlcode(self):
        obj = IbmDbTestFunctions()
        obj.assert_expectf(self.run_test_stmt_get_sqlcode)

    def run_test_stmt_get_sqlcode(self):
        conn = ibm_db.connect(config.database, config.user, config.password)
        if conn:
            result = ''
            result2 = ''
            try:
                result = ibm_db.exec_immediate(conn,"insert int0 t_string values(123,1.222333,'one to one')")
            except:
                pass
            if result:
                cols = ibm_db.num_fields(result)
                print("col:", cols,", ")
                rows = ibm_db.num_rows(result)
                print("affected row:", rows)
            else:
                print(ibm_db.get_sqlcode())
            try:
                result = ibm_db.exec_immediate(conn,"delete from t_string where a=123")
            except:
                pass
            if result:
                cols = ibm_db.num_fields(result)
                print("col:", cols,", ")
                rows = ibm_db.num_rows(result)
                print("affected row:", rows)
            else:
                print(ibm_db.get_sqlcode())

        else:
            print("no connection")

#__END__
#__LUW_EXPECTED__
#SQLCODE=-104
#__ZOS_EXPECTED__
#SQLCODE=-104
#__SYSTEMI_EXPECTED__
#SQLCODE=-104
#__IDS_EXPECTED__
#SQLCODE=-201



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import os
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_144_BindParamInsertStmtPARAM_FILE(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_144)

    def run_test_144(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        if conn:
            # Drop the test table, in case it exists
            drop = 'DROP TABLE pictures'
            try:
                result = ibm_db.exec_immediate(conn, drop)
            except:
                pass

            # Create the test table
            create = 'CREATE TABLE pictures (id INTEGER, picture BLOB)'
            result = ibm_db.exec_immediate(conn, create)

            stmt = ibm_db.prepare(conn, "INSERT INTO pictures VALUES (0, ?)")

            picture = os.path.dirname(os.path.abspath(__file__)) + "/pic1.jpg"
            if sys.platform == 'zos':
                rc = ibm_db.bind_param(stmt, 1, picture, ibm_db.SQL_PARAM_INPUT, ibm_db.SQL_BLOB)
            else:
                rc = ibm_db.bind_param(stmt, 1, picture, ibm_db.SQL_PARAM_INPUT, ibm_db.SQL_BINARY)

            rc = ibm_db.execute(stmt)

            num = ibm_db.num_rows(stmt)

            print(num)
        else:
            print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#1
#__ZOS_EXPECTED__
#1
#__SYSTEMI_EXPECTED__
#1
#__IDS_EXPECTED__
#1



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_6561_InsertNULLValues(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_6561)

    def run_test_6561(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        if conn:
            ibm_db.autocommit(conn, ibm_db.SQL_AUTOCOMMIT_OFF)

            stmt = ibm_db.exec_immediate(conn, "INSERT INTO animals (id, breed, name, weight) VALUES (null, null, null, null)")
            statement = "SELECT count(id) FROM animals"
            result = ibm_db.exec_immediate(conn, statement)
            if ( (not result) and ibm_db.stmt_error() ):
                print("ERROR: %s" % (ibm_db.stmt_errormsg(), ))

            row = ibm_db.fetch_tuple(result)
            while ( row ):
                for i in row:
                    print(i)
                row = ibm_db.fetch_tuple(result)

            ibm_db.rollback(conn)
            ibm_db.close(conn)

        else:
            print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#7
#__ZOS_EXPECTED__
#7
#__SYSTEMI_EXPECTED__
#7
#__IDS_EXPECTED__
#7



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions
import getpass

class IbmDbTestCase(unittest.TestCase):

    def test_146_CallSPINAndOUTParams(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_146)

    def run_test_146(self):
        conn = ibm_db.connect(config.database, config.user, config.password)
        server = ibm_db.server_info( conn )

        if conn:
            name = "Peaches"
            second_name = "Rickety Ride"
            weight = 0

            print("Values of bound parameters _before_ CALL:")
            print("  1: %s 2: %s 3: %d\n" % (name, second_name, weight))

            if('zos' in sys.platform):
                proc_name = getpass.getuser() + ".MATCH_ANIMAL"
            else:
                proc_name = "match_animal"
            stmt, name, second_name, weight = ibm_db.callproc(conn, proc_name, (name, second_name, weight))

            if stmt is not None:
                print("Values of bound parameters _after_ CALL:")
                print("  1: %s 2: %s 3: %d\n" % (name, second_name, weight))

                if (server.DBMS_NAME[0:3] != 'IDS'):
                    print("Results:")
                    row = ibm_db.fetch_tuple(stmt)
                    while ( row ):
                        print("  %s, %s, %s" % (row[0].strip(), row[1].strip(), row[2]))
                        row = ibm_db.fetch_tuple(stmt)

#__END__
#__LUW_EXPECTED__
#Values of bound parameters _before_ CALL:
#  1: Peaches 2: Rickety Ride 3: 0
#
#Values of bound parameters _after_ CALL:
#  1: Peaches 2: TRUE 3: 12
#
#Results:
#  Peaches, dog, 12.30
#  Pook, cat, 3.20
#  Rickety Ride, goat, 9.70
#  Smarty, horse, 350.00
#  Sweater, llama, 150.00
#__ZOS_EXPECTED__
#Values of bound parameters _before_ CALL:
#  1: Peaches 2: Rickety Ride 3: 0
#
#Values of bound parameters _after_ CALL:
#  1: Peaches 2: TRUE 3: 12
#
#Results:
#  Peaches, dog, 12.30
#  Pook, cat, 3.20
#  Rickety Ride, goat, 9.70
#  Smarty, horse, 350.00
#  Sweater, llama, 150.00
#__SYSTEMI_EXPECTED__
#Values of bound parameters _before_ CALL:
#  1: Peaches 2: Rickety Ride 3: 0
#
#Values of bound parameters _after_ CALL:
#  1: Peaches 2: TRUE 3: 12
#
#Results:
#  Peaches, dog, 12.30
#  Pook, cat, 3.20
#  Rickety Ride, goat, 9.70
#  Smarty, horse, 350.00
#  Sweater, llama, 150.00
#__IDS_EXPECTED__
#Values of bound parameters _before_ CALL:
#  1: Peaches 2: Rickety Ride 3: 0
#
#Values of bound parameters _after_ CALL:
#  1: Peaches 2: TRUE 3: 12
#



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2013
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

def strip_bom(s):
    return s[1:] if (s and s[0] in (u'\ufeff', u'\uffef')) else s

class IbmDbTestCase(unittest.TestCase):

    def test_265_NoAffectedRows(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_265)

    def run_test_265(self):
        # Make a connection
        conn = ibm_db.connect(config.database, config.user, config.password)

        cursor_option = {ibm_db.SQL_ATTR_CURSOR_TYPE: ibm_db.SQL_CURSOR_STATIC}

        if conn:
            server = ibm_db.server_info( conn )
            if (server.DBMS_NAME[0:3] == 'IDS'):
                op = {ibm_db.ATTR_CASE: ibm_db.CASE_UPPER}
                ibm_db.set_option(conn, op, 1)

            try:
                sql = 'drop table test'

                stmt = ibm_db.prepare(conn, sql)
                if sys.platform != 'zos':
                    ibm_db.set_option(stmt, cursor_option, 0)
                ibm_db.execute(stmt)
            except:
                pass

            if ((server.DBMS_NAME[0:3] == 'IDS') or (server.DBMS_NAME[0:2] == "AS")):
                sql = "create table test(id integer, name VARCHAR(10), clob_col CLOB, some_var VARCHAR(100) )"
            else:
                sql = "create table test(id integer, name VARCHAR(10), clob_col CLOB, some_var XML )"

            stmt = ibm_db.prepare(conn, sql)
            if sys.platform != 'zos':
                ibm_db.set_option(stmt, cursor_option, 0)
            ibm_db.execute(stmt)
            print("Number of affected rows: %d" % ibm_db.get_num_result(stmt))

            sql = 'select id from test'

            stmt = ibm_db.prepare(conn, sql)
            ibm_db.set_option(stmt, cursor_option, 0)
            ibm_db.execute(stmt)
            print("Number of affected rows: %d" % ibm_db.get_num_result(stmt))

            sql = "insert into test values( 1, 'some', 'here is a clob value', '<?xml version=\"1.0\" encoding=\"UTF-8\" ?><test attribute=\"value\"/>')"

            stmt = ibm_db.prepare(conn, sql)
            ibm_db.set_option(stmt, cursor_option, 0)
            ibm_db.execute(stmt)
            print("Number of affected rows: %d" % ibm_db.get_num_result(stmt))

            sql = "insert into test values(2, 'value', 'clob data', NULL)"

            stmt = ibm_db.prepare(conn, sql)
            ibm_db.set_option(stmt, cursor_option, 0)
            ibm_db.execute(stmt)
            print("Number of affected rows: %d" % ibm_db.get_num_result(stmt))

            sql = "insert into test values(2, 'in varchar', 'data2', NULL)"

            stmt = ibm_db.prepare(conn, sql)
            ibm_db.set_option(stmt, cursor_option, 0)
            ibm_db.execute(stmt)
            print("Number of affected rows: %d" % ibm_db.get_num_result(stmt))

            sql = 'select * from test'

            stmt = ibm_db.prepare(conn, sql)
            ibm_db.set_option(stmt, cursor_option, 0)
            ibm_db.execute(stmt)
            print("Number of affected rows: %d" % ibm_db.get_num_result(stmt))
            row = ibm_db.fetch_tuple(stmt)
            while ( row ):
                print("%s, %s, %s, %s\n" %(row[0], row[1], row[2], strip_bom(row[3])))
                row = ibm_db.fetch_tuple(stmt)

            sql = 'select id, name from test where id = ?'

            stmt = ibm_db.prepare(conn, sql)
            ibm_db.set_option(stmt, cursor_option, 0)
            ibm_db.execute(stmt, (2,))
            print("Number of affected rows: %d" % ibm_db.get_num_result(stmt))
            row = ibm_db.fetch_tuple(stmt)
            while ( row ):
                print("%s, %s\n" %(row[0], row[1]))
                row = ibm_db.fetch_tuple(stmt)

            if (server.DBMS_NAME[0:3] == 'IDS'):
                sql = "select * from test"
            else:
                sql = 'select * from test fetch first 12 rows only optimize for 12 rows'

            stmt = ibm_db.prepare(conn, sql)
            ibm_db.set_option(stmt, cursor_option, 0)
            #ibm_db.num_fields(stmt)
            ibm_db.execute(stmt)
            print("Number of affected rows: %d" % ibm_db.get_num_result(stmt))
            row = ibm_db.fetch_tuple(stmt)
            while ( row ):
                print("%s, %s, %s, %s\n" % (row[0], row[1], row[2], strip_bom(row[3])))
                row = ibm_db.fetch_tuple(stmt)

            try:
                sql = 'drop table test'

                stmt = ibm_db.prepare(conn, sql)
                ibm_db.set_option(stmt, cursor_option, 0)
                ibm_db.execute(stmt)
                print("Number of affected rows: %d" % ibm_db.get_num_result(stmt))
            except:
                pass

            ibm_db.close(conn)

#__END__
#__LUW_EXPECTED__
#Number of affected rows: -1
#Number of affected rows: 0
#Number of affected rows: -1
#Number of affected rows: -1
#Number of affected rows: -1
#Number of affected rows: -1
#1, some, here is a clob value, <?xml version="1.0" encoding="UTF-16" ?><test attribute="value"/>
#2, value, clob data, None
#2, in varchar, data2, None
#Number of affected rows: 2
#2, value
#2, in varchar
#Number of affected rows: -1
#1, some, here is a clob value, <?xml version="1.0" encoding="UTF-16" ?><test attribute="value"/>
#2, value, clob data, None
#2, in varchar, data2, None
#Number of affected rows: -1
#__ZOS_EXPECTED__
#Number of affected rows: -1
#Number of affected rows: 0
#Number of affected rows: -1
#Number of affected rows: -1
#Number of affected rows: -1
#Number of affected rows: 3
#1, some, here is a clob value, <?xml version="1.0" encoding="UTF-16" ?><test attribute="value"/>
#2, value, clob data, None
#2, in varchar, data2, None
#Number of affected rows: 2
#2, value
#2, in varchar
#Number of affected rows: 3
#1, some, here is a clob value, <?xml version="1.0" encoding="UTF-16" ?><test attribute="value"/>
#2, value, clob data, None
#2, in varchar, data2, None
#Number of affected rows: -1
#__SYSTEMI_EXPECTED__
#Number of affected rows: -2
#Number of affected rows: 0
#Number of affected rows: -2
#Number of affected rows: -1
#Number of affected rows: -2
#Number of affected rows: 0
#1, some, here is a clob value, <?xml version="1.0" encoding="UTF-16" ?><test attribute="value"/>
#2, value, clob data, None
#2, in varchar, data2, None
#Number of affected rows: 2
#2, value
#2, in varchar
#Number of affected rows: 0
#1, some, here is a clob value, <?xml version="1.0" encoding="UTF-16" ?><test attribute="value"/>
#2, value, clob data, None
#2, in varchar, data2, None
#Number of affected rows: -2
#__IDS_EXPECTED__
#Number of affected rows: -1
#Number of affected rows: -1
#Number of affected rows: -1
#Number of affected rows: -1
#Number of affected rows: -1
#Number of affected rows: 3
#1, some, here is a clob value, <?xml version="1.0" encoding="UTF-16" ?><test attribute="value"/>
#2, value, clob data, None
#2, in varchar, data2, None
#Number of affected rows: 2
#2, value
#2, in varchar
#Number of affected rows: 3
#1, some, here is a clob value, <?xml version="1.0" encoding="UTF-16" ?><test attribute="value"/>
#2, value, clob data, None
#2, in varchar, data2, None
#Number of affected rows: -1



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#
# NOTE: IDS requires that you pass the schema name (cannot pass None)

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_197_StatisticsIndexes(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_197)

    def run_test_197(self):
        conn = ibm_db.connect(config.database, config.user, config.password)
        server = ibm_db.server_info( conn )

        if conn:
            try:
                rc = ibm_db.exec_immediate(conn, "DROP TABLE index_test")
            except:
                pass
            rc = ibm_db.exec_immediate(conn, "CREATE TABLE index_test (id INTEGER, data VARCHAR(50))")
            rc = ibm_db.exec_immediate(conn, "CREATE UNIQUE INDEX index1 ON index_test (id)")

            print("Test first index table:")
            if (server.DBMS_NAME[0:3] == 'IDS'):
                result = ibm_db.statistics(conn,None,config.user,"index_test",True)
            elif ( sys.platform == 'zos'):
                result = ibm_db.statistics(conn,None,config.user,"INDEX_TEST",True)
            else:
                result = ibm_db.statistics(conn,None,None,"INDEX_TEST",True)
            row = ibm_db.fetch_tuple(result)
            ## skipping table info row. statistics returns informtation about table itself for informix ###
            if (server.DBMS_NAME[0:3] == 'IDS'):
                row = ibm_db.fetch_tuple(result)
            print(row[2])  # TABLE_NAME
            print(row[3])  # NON_UNIQUE
            print(row[5])  # INDEX_NAME
            print(row[8])  # COLUMN_NAME

            try:
                rc = ibm_db.exec_immediate(conn, "DROP TABLE index_test2")
            except:
                pass
            rc = ibm_db.exec_immediate(conn, "CREATE TABLE index_test2 (id INTEGER, data VARCHAR(50))")
            rc = ibm_db.exec_immediate(conn, "CREATE INDEX index2 ON index_test2 (data)")

            print("Test second index table:")
            if (server.DBMS_NAME[0:3] == 'IDS'):
                result = ibm_db.statistics(conn,None,config.user,"index_test2",True)
            elif ( sys.platform == 'zos'):
                result = ibm_db.statistics(conn,None,config.user,"INDEX_TEST2",True)
            else:
                result = ibm_db.statistics(conn,None,None,"INDEX_TEST2",True)
            row = ibm_db.fetch_tuple(result)
            ### skipping table info row. statistics returns informtation about table itself for informix ###
            if (server.DBMS_NAME[0:3] == 'IDS'):
                row = ibm_db.fetch_tuple(result)
            print(row[2])  # TABLE_NAME
            print(row[3])  # NON_UNIQUE
            print(row[5])  # INDEX_NAME
            print(row[8])  # COLUMN_NAME

            print("Test non-existent table:")
            if (server.DBMS_NAME[0:3] == 'IDS'):
                result = ibm_db.statistics(conn,None,config.user,"non_existent_table",True)
            else:
                result = ibm_db.statistics(conn,None,None,"NON_EXISTENT_TABLE",True)
            row = ibm_db.fetch_tuple(result)
            if row:
                print("Non-Empty")
            else:
                print("Empty")
        else:
            print('no connection: ' + ibm_db.conn_errormsg())

#__END__
#__LUW_EXPECTED__
#Test first index table:
#INDEX_TEST
#0
#INDEX1
#ID
#Test second index table:
#INDEX_TEST2
#1
#INDEX2
#DATA
#Test non-existent table:
#Empty
#__ZOS_EXPECTED__
#Test first index table:
#INDEX_TEST
#0
#INDEX1
#ID
#Test second index table:
#INDEX_TEST2
#1
#INDEX2
#DATA
#Test non-existent table:
#Empty
#__SYSTEMI_EXPECTED__
#Test first index table:
#INDEX_TEST
#0
#INDEX1
#ID
#Test second index table:
#INDEX_TEST2
#1
#INDEX2
#DATA
#Test non-existent table:
#Empty
#__IDS_EXPECTED__
#Test first index table:
#index_test
#0
#index1
#id
#Test second index table:
#index_test2
#1
#index2
#data
#Test non-existent table:
#Empty



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#
# NOTE: IDS does not support XML as a native datatype (test is invalid for IDS)

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

def strip_bom(s):
    return s[1:] if (s and s[0] in (u'\ufeff', u'\uffef')) else s

class IbmDbTestCase(unittest.TestCase):

    def test_196_InsertRetrieveXMLData_02(self):
        obj = IbmDbTestFunctions()
        obj.assert_expectf(self.run_test_196)

    def run_test_196(self):
        conn = ibm_db.connect(config.database, config.user, config.password)
        server = ibm_db.server_info( conn )

        if ((server.DBMS_NAME[0:3] != 'IDS') and (server.DBMS_NAME[0:2] != "AS")):
            try:
                rc = ibm_db.exec_immediate(conn, "DROP TABLE xml_test")
            except:
                pass
            rc = ibm_db.exec_immediate(conn, "CREATE TABLE xml_test (id INTEGER, data VARCHAR(50), xmlcol XML)")
            rc = ibm_db.exec_immediate(conn, "INSERT INTO xml_test (id, data, xmlcol) values (1, 'xml test 1', '<address><street>12485 S Pine St.</street><city>Olathe</city><state>KS</state><zip>66061</zip></address>')")

            sql =  "SELECT * FROM xml_test"
            stmt = ibm_db.prepare(conn, sql)
            ibm_db.execute(stmt)
            result = ibm_db.fetch_both(stmt)
            while( result ):
                print("Result ID:", result[0])
                print("Result DATA:", result[1])
                print("Result XMLCOL:", strip_bom(result[2]))
                result = ibm_db.fetch_both(stmt)

            sql = "SELECT XMLSERIALIZE(XMLQUERY('for $i in $t/address where $i/city = \"Olathe\" return <zip>{$i/zip/text()}</zip>' passing c.xmlcol as \"t\") AS CLOB(32k)) FROM xml_test c WHERE id = 1"
            stmt = ibm_db.prepare(conn, sql)
            ibm_db.execute(stmt)
            result = ibm_db.fetch_both(stmt)
            while( result ):
                print("Result from XMLSerialize and XMLQuery:", strip_bom(result[0]))
                result = ibm_db.fetch_both(stmt)

            sql = "select xmlquery('for $i in $t/address where $i/city = \"Olathe\" return <zip>{$i/zip/text()}</zip>' passing c.xmlcol as \"t\") from xml_test c where id = 1"
            stmt = ibm_db.prepare(conn, sql)
            ibm_db.execute(stmt)
            result = ibm_db.fetch_both(stmt)
            while( result ):
                print("Result from only XMLQuery:", strip_bom(result[0]))
                result = ibm_db.fetch_both(stmt)
        else:
            print('Native XML datatype is not supported.')

#__END__
#__LUW_EXPECTED__
#Result ID: 1
#Result DATA: xml test 1
#Result XMLCOL:%s<address><street>12485 S Pine St.</street><city>Olathe</city><state>KS</state><zip>66061</zip></address>
#Result from XMLSerialize and XMLQuery: <zip>66061</zip>
#Result from only XMLQuery:%s<zip>66061</zip>
#__ZOS_EXPECTED__
#Result ID: 1
#Result DATA: xml test 1
#Result XMLCOL:%s<address><street>12485 S Pine St.</street><city>Olathe</city><state>KS</state><zip>66061</zip></address>
#Result from XMLSerialize and XMLQuery: <zip>66061</zip>
#Result from only XMLQuery:%s<zip>66061</zip>
#__SYSTEMI_EXPECTED__
#Native XML datatype is not supported.
#__IDS_EXPECTED__
#Native XML datatype is not supported.



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_311_InsertSelectDeleteNumLiterals(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_311)

    def run_test_311(self):
        # Make a connection
        conn = ibm_db.connect(config.database, config.user, config.password)

        if conn:
            ibm_db.autocommit(conn, ibm_db.SQL_AUTOCOMMIT_ON )

            # Drop the tab_num_literals table, in case it exists
            drop = 'DROP TABLE tab_num_literals'
            result = ''
            try:
                result = ibm_db.exec_immediate(conn, drop)
            except:
                pass
            # Create the animal table
            create = "CREATE TABLE tab_num_literals (col1 INTEGER, col2 FLOAT, col3 DECIMAL(7,2))"
            result = ibm_db.exec_immediate(conn, create)

            insert = "INSERT INTO tab_num_literals values ('11.22', '33.44', '55.66')"
            res = ibm_db.exec_immediate(conn, insert)
            print("Number of inserted rows:", ibm_db.num_rows(res))

            stmt = ibm_db.prepare(conn, "SELECT col1, col2, col3 FROM tab_num_literals WHERE col1 = '11'")
            ibm_db.execute(stmt)
            data = ibm_db.fetch_both(stmt)
            while ( data ):
                print(data[0])
                print(data[1])
                print(data[2])
                data = ibm_db.fetch_both(stmt)

            sql = "UPDATE tab_num_literals SET col1 = 77 WHERE col2 = 33.44"
            res = ibm_db.exec_immediate(conn, sql)
            print("Number of updated rows:", ibm_db.num_rows(res))

            stmt = ibm_db.prepare(conn, "SELECT col1, col2, col3 FROM tab_num_literals WHERE col2 > '33'")
            ibm_db.execute(stmt)
            data = ibm_db.fetch_both(stmt)
            while ( data ):
                print(data[0])
                print(data[1])
                print(data[2])
                data = ibm_db.fetch_both(stmt)

            sql = "DELETE FROM tab_num_literals WHERE col1 > '10.0'"
            res = ibm_db.exec_immediate(conn, sql)
            print("Number of deleted rows:", ibm_db.num_rows(res))

            stmt = ibm_db.prepare(conn, "SELECT col1, col2, col3 FROM tab_num_literals WHERE col3 < '56'")
            ibm_db.execute(stmt)
            data = ibm_db.fetch_both(stmt)
            while ( data ):
                print(data[0])
                print(data[1])
                print(data[2])
                data = ibm_db.fetch_both(stmt)

            ibm_db.rollback(conn)
            ibm_db.close(conn)

#__END__
#__LUW_EXPECTED__
#Number of inserted rows: 1
#11
#33.44
#55.66
#Number of updated rows: 1
#77
#33.44
#55.66
#Number of deleted rows: 1
#__ZOS_EXPECTED__
#Number of inserted rows: 1
#11
#33.44
#55.66
#Number of updated rows: 1
#77
#33.44
#55.66
#Number of deleted rows: 1
#__SYSTEMI_EXPECTED__
#Number of inserted rows: 1
#11
#33.44
#55.66
#Number of updated rows: 1
#77
#33.44
#55.66
#Number of deleted rows: 1
#__IDS_EXPECTED__
#Number of inserted rows: 1
#11
#33.44
#55.66
#Number of updated rows: 1
#77
#33.44
#55.66
#Number of deleted rows: 1



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import ibm_db_dbi
import config
from testfunctions import IbmDbTestFunctions


class IbmDbTestCase(unittest.TestCase):

    def test_315_FetchAll_DBI(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_315)

    def run_test_315(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        ibm_db.autocommit(conn, ibm_db.SQL_AUTOCOMMIT_OFF)

        # Drop the test table, in case it exists
        drop = 'DROP TABLE varigraph'
        try:
            result = ibm_db.exec_immediate(conn, drop)
        except:
            pass

        # Create the test table
        create = 'CREATE TABLE varigraph( i INT, g VARGRAPHIC(10000))'
        result = ibm_db.exec_immediate(conn, create)

        vargraphic_string = "a" * 8192

        insert_sql = "INSERT INTO varigraph (i, g) VALUES (?, ?)"
        stmt = ibm_db.prepare(conn, insert_sql)

        ibm_db.bind_param(stmt, 1, 0)
        ibm_db.bind_param(stmt, 2, 'hogehoge')
        ibm_db.execute(stmt)

        ibm_db.bind_param(stmt, 1, 1)
        ibm_db.bind_param(stmt, 2, vargraphic_string)
        ibm_db.execute(stmt)

        db2_conn = ibm_db_dbi.Connection(conn)
        db2_cur = db2_conn.cursor()

        sql = "SELECT i, length(g||g) FROM varigraph"

        try:
            db2_conn.cursor()
            db2_cur.execute(sql)
            for (i, len) in db2_cur.fetchall():
                print("i: {} , len: {} ".format(i, len))
        except:
            err = ibm_db.stmt_errormsg()
            print(err)

#__END__
#__LUW_EXPECTED__
#[IBM][CLI Driver][DB2/LINUXX8664] SQL0137N  The length resulting from "CONCAT" is greater than "0000016350 ".  SQLSTATE=54006  SQLCODE=-137
#__ZOS_EXPECTED__
#[IBM][CLI Driver][DB2/LINUXX8664] SQL0137N  The length resulting from "CONCAT" is greater than "0000016350 ".  SQLSTATE=54006  SQLCODE=-137
#__SYSTEMI_EXPECTED__
#[IBM][CLI Driver][AS] SQL0137N  The length resulting from "CONCAT" is greater than "0000016350 ".  SQLSTATE=54006  SQLCODE=-137
#__IDS_EXPECTED__
#[IBM][CLI Driver][IDS/LINUXX8664] SQL0137N  The length resulting from "CONCAT" is greater than "0000016350 ".  SQLSTATE=54006  SQLCODE=-137



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import os
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):
    @unittest.skipIf((sys.platform == 'zos'), "Test fails in zOS")
    def test_execute_many(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_execute_many)

    def run_test_execute_many(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        server = ibm_db.server_info( conn )

        if( not server.DBMS_NAME.startswith('DB2/')):
            print("Boolean is not supported")
            return 0

        if conn:
            # Drop the tabmany table, in case it exists
            drop = "DROP TABLE TABMANY"
            try:
                result = ibm_db.exec_immediate(conn, drop)
            except:
                pass

            #create table tabmany
            create = "CREATE TABLE TABMANY(id SMALLINT NOT NULL, name VARCHAR(32), bflag boolean)"
            ibm_db.exec_immediate(conn, create)

            #Populate the tabmany table with execute_many
            insert = "INSERT INTO TABMANY (id, name, bflag) VALUES(?, ?, ?)"
            params = ((10, 'Sanders', True), (20, 'Pernal', False), (30, 'Marenghi', True), (40, 'OBrien', False))
            stmt_insert = ibm_db.prepare(conn, insert)
            ibm_db.execute_many(stmt_insert, params)
            #check the number of rows inserted
            row_count = ibm_db.num_rows(stmt_insert)
            print(row_count)

            # check the inserted columns
            select = "SELECT * FROM TABMANY"
            stmt_select = ibm_db.exec_immediate(conn, select)
            cols = ibm_db.fetch_tuple( stmt_select )
            while( cols ):
                print("%s, %s, %s" % (cols[0], cols[1], cols[2]))
                cols = ibm_db.fetch_tuple( stmt_select )

            #populate the tabmany table
            params = ((50, 'Hanes', False), (55, 'Mike', False, 'Extra'), (55.5, 'invalid row','not a bool'), (60, 'Quigley'), (70, None, None), [75, 'List', True] )
            try:
                ibm_db.execute_many(stmt_insert, params)
            except Exception as inst:
                #check the no. of inserted rows
                row_count = ibm_db.num_rows(stmt_insert)
                #check the exception raised by execute_many API
                print(inst)
                print(row_count)
            ibm_db.close(conn)

        else:
            print(ibm_db.conn_errormsg())

#__END__
#__LUW_EXPECTED__
#4
#10, Sanders, True
#20, Pernal, False
#30, Marenghi, True
#40, OBrien, False
#Error 1: Value parameter tuple 2 has more parameters than previous tuple
#Error 2: Value parameter tuple 3 has types that are not homogeneous with previous tuple
#Error 3: Value parameter tuple 4 has fewer parameters than previous tuple
#Error 4: Value parameter 6 is not a tuple
#2
#__ZOS_EXPECTED__
#Boolean is not supported
#__SYSTEMI_EXPECTED__
#NA
#__IDS_EXPECTED__
#4
#10, Sanders, True
#20, Pernal, False
#30, Marenghi, True
#40, OBrien, False
#Error 1: Value parameter tuple 2 has more parameters than previous tuple
#Error 2: Value parameter tuple 3 has types that are not homogeneous with previous tuple
#Error 3: Value parameter tuple 4 has fewer parameters than previous tuple
#Error 4: Value parameter 6 is not a tuple
#2



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_022_RollbackInsert(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_022)

    def run_test_022(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        if conn:
            stmt = ibm_db.exec_immediate(conn, "SELECT count(*) FROM animals")
            res = ibm_db.fetch_tuple(stmt)
            rows = res[0]
            print(rows)

            ibm_db.autocommit(conn, 0)
            ac = ibm_db.autocommit(conn)
            if ac != 0:
                print("Cannot set ibm_db.AUTOCOMMIT_OFF\nCannot run test")
                #continue

            ibm_db.exec_immediate(conn, "INSERT INTO animals values (7,'bug','Brain Bug',10000.1)")

            stmt = ibm_db.exec_immediate(conn, "SELECT count(*) FROM animals")
            res = ibm_db.fetch_tuple(stmt)
            rows = res[0]
            print(rows)

            ibm_db.rollback(conn)

            stmt = ibm_db.exec_immediate(conn, "SELECT count(*) FROM animals")
            res = ibm_db.fetch_tuple(stmt)
            rows = res[0]
            print(rows)
            ibm_db.close(conn)
        else:
            print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#7
#8
#7
#__ZOS_EXPECTED__
#7
#8
#7
#__SYSTEMI_EXPECTED__
#7
#8
#7
#__IDS_EXPECTED__
#7
#8
#7



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_002_ConnDbUncatalogedConn(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_002)

    def run_test_002(self):
        conn_str = "DATABASE=%s;HOSTNAME=%s;PORT=%d;PROTOCOL=TCPIP;UID=%s;PWD=%s;" % (config.database, config.hostname, config.port, config.user, config.password)
        conn = ibm_db.connect(conn_str, '', '')

        if conn:
            print ("Connection succeeded.")
            ibm_db.close(conn)
        else:
            print ("Connection failed.")

#__END__
#__LUW_EXPECTED__
#Connection succeeded.
#__ZOS_EXPECTED__
#Connection succeeded.
#__SYSTEMI_EXPECTED__
#Connection succeeded.
#__IDS_EXPECTED__
#Connection succeeded.



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
import platform

from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):
    @unittest.skipIf(platform.system() == 'z/OS',"Test fails with z/OS ODBC driver")
    def test_116_ConnActive(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_116)

    def run_test_116(self):
        conn = None
        is_alive = ibm_db.active(conn)
        if is_alive:
            print("Is active")
        else:
            print("Is not active")

        conn = ibm_db.connect(config.database, config.user, config.password)
        is_alive = ibm_db.active(conn)
        if is_alive:
            print("Is active")
        else:
            print("Is not active")

        ibm_db.close(conn)
        is_alive = ibm_db.active(conn)
        if is_alive:
            print("Is active")
        else:
            print("Is not active")

        # Executing active method multiple times to reproduce a customer reported defect
        print(ibm_db.active(conn))
        print(ibm_db.active(conn))
        print(ibm_db.active(conn))
        conn = ibm_db.connect(config.database, config.user, config.password)
        print(ibm_db.active(conn))
        print(ibm_db.active(conn))
        print(ibm_db.active(conn))

#__END__
#__LUW_EXPECTED__
#Is not active
#Is active
#Is not active
#False
#False
#False
#True
#True
#True
#__ZOS_EXPECTED__
#Is not active
#Is active
#Is not active
#False
#False
#False
#True
#True
#True
#__SYSTEMI_EXPECTED__
#Is not active
#Is active
#Is not active
#False
#False
#False
#True
#True
#True
#__IDS_EXPECTED__
#Is not active
#Is active
#Is not active
#False
#False
#False
#True
#True
#True



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_019_selectRowcountPrefetchPrepOpt(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_019)

    def run_test_019(self):
        conn = ibm_db.connect(config.database, config.user, config.password)
        ibm_db.autocommit(conn, ibm_db.SQL_AUTOCOMMIT_ON)
        if conn:
            if('zos' in sys.platform):
                stmt = ibm_db.prepare(conn, "SELECT * from animals WHERE weight < 10.0")
            else:
                stmt = ibm_db.prepare(conn, "SELECT * from animals WHERE weight < 10.0", {ibm_db.SQL_ATTR_ROWCOUNT_PREFETCH : ibm_db.SQL_ROWCOUNT_PREFETCH_ON} )
            result = ibm_db.execute(stmt)
            if result:
                rows = ibm_db.num_rows(stmt)
                print("affected row:", rows)
                ibm_db.free_result(stmt)
            else:
                print(ibm_db.stmt_errormsg())

            ibm_db.close(conn)
        else:
            print("no connection:", ibm_db.conn_errormsg())

#__END__
#__LUW_EXPECTED__
#affected row: 4
#__ZOS_EXPECTED__
#affected row: 4
#__SYSTEMI_EXPECTED__
#affected row: 4
#__IDS_EXPECTED__
#affected row: 4
#__ZOS_ODBC_EXPECTED__
#affected row: -1



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_211_FieldDisplaySize_02(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_211)

    def run_test_211(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        result = ibm_db.exec_immediate(conn, "select * from sales")

        i = 1

        while (i <= ibm_db.num_fields(result)):
            #printf("%d size %d\n",i, ibm_db.field_display_size(result,i) || 0)
            print("%d size %d" % (i, ibm_db.field_display_size(result,i) or 0))
            i += 1

        ibm_db.close(conn)

#__END__
#__LUW_EXPECTED__
#1 size 15
#2 size 15
#3 size 11
#4 size 0
#__ZOS_EXPECTED__
#1 size 15
#2 size 15
#3 size 11
#4 size 0
#__SYSTEMI_EXPECTED__
#1 size 15
#2 size 15
#3 size 11
#4 size 0
#__IDS_EXPECTED__
#1 size 15
#2 size 15
#3 size 11
#4 size 0



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_064_Tables_05(self):
        obj = IbmDbTestFunctions()
        obj.assert_expectf(self.run_test_064)

    def run_test_064(self):
        conn = ibm_db.connect(config.database, config.user, config.password)
        server = ibm_db.server_info( conn )

        create = 'CREATE SCHEMA AUTHORIZATION t'
        try:
            result = ibm_db.exec_immediate(conn, create)
        except:
            pass

        create = 'CREATE TABLE t.t1( c1 integer, c2 varchar(40))'
        try:
            result = ibm_db.exec_immediate(conn, create)
        except:
            pass

        create = 'CREATE TABLE t.t2( c1 integer, c2 varchar(40))'
        try:
            result = ibm_db.exec_immediate(conn, create)
        except:
            pass

        create = 'CREATE TABLE t.t3( c1 integer, c2 varchar(40))'
        try:
            result = ibm_db.exec_immediate(conn, create)
        except:
            pass

        create = 'CREATE TABLE t.t4( c1 integer, c2 varchar(40))'
        try:
            result = ibm_db.exec_immediate(conn, create)
        except:
            pass

        if (server.DBMS_NAME[0:3] == 'IDS'):
            result = ibm_db.tables(conn, None, 't')
        else:
            result = ibm_db.tables(conn, None, 'T')

        for i in range(0, ibm_db.num_fields(result)):
            print("%s, " % ibm_db.field_name(result, i))
        print()
        print()

        i = 0
        row = ibm_db.fetch_tuple(result)
        while ( row ):
            ibm_db.num_fields(result)
            if (i < 4):
                print(", " + row[1] + ", " + row[2] + ", " + row[3] + ", , \n")
            i = i + 1
            row = ibm_db.fetch_tuple(result)

        ibm_db.free_result(result)

        ibm_db.exec_immediate(conn, 'DROP TABLE t.t1')
        ibm_db.exec_immediate(conn, 'DROP TABLE t.t2')
        ibm_db.exec_immediate(conn, 'DROP TABLE t.t3')
        ibm_db.exec_immediate(conn, 'DROP TABLE t.t4')

#__END__
#__LUW_EXPECTED__
#TABLE_CAT, TABLE_SCHEM, TABLE_NAME, TABLE_TYPE, REMARKS, 
#
#, T, T1, TABLE, , 
#, T, T2, TABLE, , 
#, T, T3, TABLE, , 
#, T, T4, TABLE, , 
#__ZOS_EXPECTED__
#TABLE_CAT, TABLE_SCHEM, TABLE_NAME, TABLE_TYPE, REMARKS, 
#
#, T, T1, TABLE, , 
#, T, T2, TABLE, , 
#, T, T3, TABLE, , 
#, T, T4, TABLE, , 
#__SYSTEMI_EXPECTED__
#TABLE_CAT, TABLE_SCHEM, TABLE_NAME, TABLE_TYPE, REMARKS, 
#
#, T, T1, TABLE, , 
#, T, T2, TABLE, , 
#, T, T3, TABLE, , 
#, T, T4, TABLE, , 
#__IDS_EXPECTED__
#table_cat, table_schem, table_name, table_type, remarks, 
#
#, t, t1, TABLE%s, , 
#, t, t2, TABLE%s, , 
#, t, t3, TABLE%s, , 
#, t, t4, TABLE%s, ,



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2025
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import ibm_db_dbi
import config
from testfunctions import IbmDbTestFunctions


class IbmDbTestCase(unittest.TestCase):

    def test_318_get_sqlcode_DBI(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_318)

    def run_test_318(self):
        try:
            # Intentionally wrong credentials to trigger connection failure
            conn = ibm_db_dbi.connect(config.database, "wrongUser", "wrongPassword")
            print(conn)  # Should not get here
        except Exception:
            print(ibm_db_dbi.get_sqlcode())

        try:
            conn1 = ibm_db_dbi.connect(config.database, config.user, config.password)
            cursor = conn1.cursor()
            cursor.execute("create table index_test(id int, data VARCHAR(50)")
        except Exception:
            print(ibm_db_dbi.get_sqlcode())

#__END__
#__LUW_EXPECTED__
#SQLCODE=-30082
#SQLCODE=-104
#__ZOS_EXPECTED__
#SQLCODE=-30082
#SQLCODE=-104
#__SYSTEMI_EXPECTED__
#SQLCODE=-30082
#SQLCODE=-104
#__IDS_EXPECTED__
#SQLCODE=-30082
#SQLCODE=-104



import ibm_db

class Db2connect:
    """Context manager to handle connections to DB2."""
    #__cxn: Optional['IBM_DBConnection'] 
    
    def __init__(self, dsn: str, username: str, password: str) -> None:
        """Instantiate a DB2 connection."""
        #print("init method called")
        self.__dsn = dsn
        self.__username = username
        self.__password = password
        self.__cxn = None

    def __enter__(self) -> 'IBM_DBConnection':
        """Connect to DB2."""
        self.__cxn = ibm_db.connect(self.__dsn, '', '')
        #print("enter method called")
        return self.__cxn

    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
        """Disconnect from DB2."""
        #print("exit method called")
        ibm_db.close(self.__cxn)
        self.__cxn = None      



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_148_CallSPDiffBindPattern_01(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_148)

    def run_test_148(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        if conn:
            ##### Set up #####
            serverinfo = ibm_db.server_info( conn )
            server = serverinfo.DBMS_NAME[0:3]
            try:
                sql = "DROP TABLE sptb"
                ibm_db.exec_immediate(conn, sql)
            except:
                pass

            try:
                sql = "DROP PROCEDURE sp"
                ibm_db.exec_immediate(conn, sql)
            except:
                pass

            if (server == 'IDS'):
                sql = "CREATE TABLE sptb (c1 INTEGER, c2 FLOAT, c3 VARCHAR(10), c4 INT8, c5 CLOB)"
            else:
                sql = "CREATE TABLE sptb (c1 INTEGER, c2 FLOAT, c3 VARCHAR(10), c4 BIGINT, c5 CLOB)"

            ibm_db.exec_immediate(conn, sql)

            sql = "INSERT INTO sptb (c1, c2, c3, c4, c5) VALUES (1, 5.01, 'varchar', 3271982, 'clob data clob data')"
            ibm_db.exec_immediate(conn, sql)

            if (server == 'IDS'):
                sql = """CREATE PROCEDURE sp(OUT out1 INTEGER, OUT out2 FLOAT, OUT out3 VARCHAR(10), OUT out4 INT8, OUT out5 CLOB);
                 SELECT c1, c2, c3, c4, c5 INTO out1, out2, out3, out4, out5 FROM sptb; END PROCEDURE;"""
            else:
                sql = """CREATE PROCEDURE sp(OUT out1 INTEGER, OUT out2 FLOAT, OUT out3 VARCHAR(10), OUT out4 BIGINT, OUT out5 CLOB)
                 DYNAMIC RESULT SETS 1 LANGUAGE SQL BEGIN
                 SELECT c1, c2, c3, c4, c5 INTO out1, out2, out3, out4, out5 FROM sptb; END"""
            ibm_db.exec_immediate(conn, sql)
            #############################

            ##### Run the test #####

            out1 = 0
            out2 = 0.00
            out3 = ""
            out4 = 0
            out5 = ""

            if 'zos' == sys.platform:
                stmt, out1, out2, out3, out4, out5 = ibm_db.callproc(conn, 'SP', (out1, out2, out3, out4, out5))
            else:
                stmt, out1, out2, out3, out4, out5 = ibm_db.callproc(conn, 'sp', (out1, out2, out3, out4, out5))

            print("out 1:")
            print(out1)
            print("out 2:")
            print(out2)
            print("out 3:")
            print(out3)
            print("out 4:")
            print(out4)
            print("out 5:")
            print(out5)
            #############################
        else:
            print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#out 1:
#1
#out 2:
#5.01
#out 3:
#varchar
#out 4:
#3271982
#out 5:
#clob data clob data
#__ZOS_EXPECTED__
#out 1:
#1
#out 2:
#5.01
#out 3:
#varchar
#out 4:
#3271982
#out 5:
#clob data clob data
#__SYSTEMI_EXPECTED__
#out 1:
#1
#out 2:
#5.01
#out 3:
#varchar
#out 4:
#3271982
#out 5:
#clob data clob data
#__IDS_EXPECTED__
#out 1:
#1
#out 2:
#5.01
#out 3:
#varchar
#out 4:
#3271982
#out 5:
#clob data clob data



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#
# NOTE: IDS requires that you pass the schema name (cannot pass None)

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_191_ColumnsTable_02(self):
        obj = IbmDbTestFunctions()
        obj.assert_expectf(self.run_test_191)

    def run_test_191(self):
        conn = ibm_db.connect(config.database, config.user, config.password)
        server = ibm_db.server_info( conn )

        if conn:
            if (server.DBMS_NAME[0:3] == 'IDS'):
                result = ibm_db.columns(conn,None,config.user,"emp_photo");
            else:
                result = ibm_db.columns(conn,None,None,"EMP_PHOTO");

            i = 0
            row = ibm_db.fetch_both(result)
            while ( row ):
                if (server.DBMS_NAME[0:3] == 'IDS'):
                    if ( (row['column_name'] != 'emp_rowid') and (i < 3) ):
                        print("%s,%s,%s,%s\n" % (row['table_schem'],
                        row['table_name'], row['column_name'], row['is_nullable']))
                else :
                    if ( (row['COLUMN_NAME'] != 'EMP_ROWID') and (i < 3) ):
                        print("%s,%s,%s,%s\n" % (row['TABLE_SCHEM'],
                        row['TABLE_NAME'], row['COLUMN_NAME'], row['IS_NULLABLE']))
                i = i + 1
                row = ibm_db.fetch_both(result)
            print("done!")
        else:
            print("no connection: ", ibm_db.conn_errormsg())

#__END__
#__LUW_EXPECTED__
#%s,EMP_PHOTO,EMPNO,NO
#%s,EMP_PHOTO,PHOTO_FORMAT,NO
#%s,EMP_PHOTO,PICTURE,YES
#done!
#__ZOS_EXPECTED__
#%s,EMP_PHOTO,EMPNO,NO
#%s,EMP_PHOTO,PHOTO_FORMAT,NO
#%s,EMP_PHOTO,PICTURE,YES
#done!
#__SYSTEMI_EXPECTED__
#%s,EMP_PHOTO,EMPNO,NO
#%s,EMP_PHOTO,PHOTO_FORMAT,NO
#%s,EMP_PHOTO,PICTURE,YES
#done!
#__IDS_EXPECTED__
#%s,emp_photo,empno,NO
#%s,emp_photo,photo_format,NO
#%s,emp_photo,picture,YES
#done!



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import os
import sys
import unittest
import ibm_db
import config
import getpass
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    # Fails with AssertionError: '     ' != '08001'
    @unittest.skipIf(os.environ.get("CI", False), "Test fails in CI")
    def test_080_ConnWrongDbAlias(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_080)

    def run_test_080(self):
        try:
            if sys.platform == 'zos':
                conn =  ibm_db.connect("x", getpass.getuser(), config.password)
            else:
                conn = ibm_db.connect("x", config.user, config.password)
            print("??? No way.")
        except:
            print(ibm_db.conn_error())

        #if conn:
        #  print "??? No way."
        #else:
        #  print ibm_db.conn_error()

#__END__
#__LUW_EXPECTED__
#08001
#__ZOS_EXPECTED__
#08001
#__SYSTEMI_EXPECTED__
#08001
#__IDS_EXPECTED__
#08001
#__ZOS_ODBC_EXPECTED__
#42505



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_310_ClientInfo(self):
        obj = IbmDbTestFunctions()
        obj.assert_expectf(self.run_test_310)

    def run_test_310(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        client = ibm_db.client_info(conn)

        if client:
            print("DRIVER_NAME: string(%d) \"%s\"" % (len(client.DRIVER_NAME), client.DRIVER_NAME))
            print("DRIVER_VER: string(%d) \"%s\"" % (len(client.DRIVER_VER), client.DRIVER_VER))
            print("DATA_SOURCE_NAME: string(%d) \"%s\"" % (len(client.DATA_SOURCE_NAME), client.DATA_SOURCE_NAME))
            print("DRIVER_ODBC_VER: string(%d) \"%s\"" % (len(client.DRIVER_ODBC_VER), client.DRIVER_ODBC_VER))
            print("ODBC_VER: string(%d) \"%s\"" % (len(client.ODBC_VER), client.ODBC_VER))
            print("ODBC_SQL_CONFORMANCE: string(%d) \"%s\"" % (len(client.ODBC_SQL_CONFORMANCE), client.ODBC_SQL_CONFORMANCE))
            print("APPL_CODEPAGE: int(%s)" % client.APPL_CODEPAGE)
            print("CONN_CODEPAGE: int(%s)" % client.CONN_CODEPAGE)

            ibm_db.close(conn)
        else:
            print("Error.")

#__END__
#__LUW_EXPECTED__
#DRIVER_NAME: string(%d) %s
#DRIVER_VER: string(%d) %s
#DATA_SOURCE_NAME: string(%d) %s
#DRIVER_ODBC_VER: string(%d) %s
#ODBC_VER: string(%d) %s
#ODBC_SQL_CONFORMANCE: string(%d) %s
#APPL_CODEPAGE: int(%d)
#CONN_CODEPAGE: int(%d)
#__ZOS_EXPECTED__
#DRIVER_NAME: string(%d) %s
#DRIVER_VER: string(%d) %s
#DATA_SOURCE_NAME: string(%d) %s
#DRIVER_ODBC_VER: string(%d) %s
#ODBC_VER: string(%d) %s
#ODBC_SQL_CONFORMANCE: string(%d) %s
#APPL_CODEPAGE: int(%d)
#CONN_CODEPAGE: int(%d)
#__SYSTEMI_EXPECTED__
#DRIVER_NAME: string(%d) %s
#DRIVER_VER: string(%d) %s
#DATA_SOURCE_NAME: string(%d) %s
#DRIVER_ODBC_VER: string(%d) %s
#ODBC_VER: string(%d) %s
#ODBC_SQL_CONFORMANCE: string(%d) %s
#APPL_CODEPAGE: int(%d)
#CONN_CODEPAGE: int(%d)
#__IDS_EXPECTED__
#DRIVER_NAME: string(%d) %s
#DRIVER_VER: string(%d) %s
#DATA_SOURCE_NAME: string(%d) %s
#DRIVER_ODBC_VER: string(%d) %s
#ODBC_VER: string(%d) %s
#ODBC_SQL_CONFORMANCE: string(%d) %s
#APPL_CODEPAGE: int(%d)
#CONN_CODEPAGE: int(%d)



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_232_FieldTypePosName(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_232)

    def run_test_232(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        result = ibm_db.exec_immediate(conn, "select * from sales")

        for i in range(0, ibm_db.num_fields(result) + 1):
            field_name = ibm_db.field_name(result,i)
            field_type = ibm_db.field_type(result, ibm_db.field_name(result,i))
            print(str(ibm_db.field_name(result, i)) + ":" + str(ibm_db.field_type(result, ibm_db.field_name(result, i))))

        print("-----")

        t = ibm_db.field_type(result,99)
        print(t)

        t1 = ibm_db.field_type(result, "HELMUT")
        print(t1)

#__END__
#__LUW_EXPECTED__
#SALES_DATE:date
#SALES_PERSON:string
#REGION:string
#SALES:int
#False:False
#-----
#False
#False
#__ZOS_EXPECTED__
#SALES_DATE:date
#SALES_PERSON:string
#REGION:string
#SALES:int
#False:False
#-----
#False
#False
#__SYSTEMI_EXPECTED__
#SALES_DATE:date
#SALES_PERSON:string
#REGION:string
#SALES:int
#False:False
#-----
#False
#False
#__IDS_EXPECTED__
#sales_date:date
#sales_person:string
#region:string
#sales:int
#False:False
#-----
#False
#False



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2021
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions
from datetime import date, time, datetime
from decimal import Decimal


class IbmDbTestCase(unittest.TestCase):
    def test_alltypes(self):
        self.maxDiff = None
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_alltypes)

    def run_test_alltypes(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        if conn:
            serverinfo = ibm_db.server_info( conn )

            drop = "DROP TABLE TESTTYPES"
            try:
                result = ibm_db.exec_immediate(conn,drop)
            except:
                pass

            # Create the table of all data types
            if (serverinfo.DBMS_NAME[0:3] == 'IDS'):
                create = "CREATE TABLE TESTTYPES(C1 BIGINT, C2 BOOLEAN, C3 BOOLEAN, C4 DATE, C5 DECIMAL(16), C6 DECIMAL(34), C7 DECIMAL(16,2), C8 DECIMAL(16,2), C9 DECIMAL(16,2), C10 INTEGER, C11 BINARY(30), C12 BLOB(30), C13 Char(30), C14 CLOB(30), C15 DBCLOB(30), C16 TIMESTAMP, C17 VARBINARY(30), C18 VARChar(30), C19 TIME, C20 TIMESTAMP, C21 BINARY(40), C22 BLOB(40), C23 Char(40), C24 CLOB(40), C25 DBCLOB(40), C26 TIMESTAMP, C27 VARBINARY(40), C28 VARChar(40))"
            elif (serverinfo.DBMS_NAME =="DB2" or serverinfo.DBMS_NAME.startswith("DSN")):
                create = "CREATE TABLE TESTTYPES(C1 BIGINT, C2 DATE, C3 DECFLOAT(16), C4 DECFLOAT(34), C5 DECIMAL(16,2), C6 DECIMAL(16,2), C7 DECIMAL(16,2), C8 INTEGER, C9 BINARY(30), C10 BLOB(30), C11 Char(30), C12 CLOB(30), C13 TIMESTAMP, C14 VARChar(30), C15 TIME, C16 TIMESTAMP, C17 BINARY(40), C18 BLOB(40), C19 Char(40), C20 CLOB(40), C21 TIMESTAMP, C22 VARBINARY(40), C23 VARChar(40),C24 TIMESTAMP WITH TIMEZONE)"
            else:
                create = "CREATE TABLE TESTTYPES(C1 BIGINT, C2 BOOLEAN, C3 BOOLEAN, C4 DATE, C5 DECFLOAT(16), C6 DECFLOAT(34), C7 DECIMAL(16,2), C8 DECIMAL(16,2), C9 DECIMAL(16,2), C10 INTEGER, C11 BINARY(30), C12 BLOB(30), C13 Char(30), C14 CLOB(30), C15 DBCLOB(30), C16 TIMESTAMP, C17 VARBINARY(30), C18 VARChar(30), C19 TIME, C20 TIMESTAMP, C21 BINARY(40), C22 BLOB(40), C23 Char(40), C24 CLOB(40), C25 DBCLOB(40), C26 TIMESTAMP, C27 VARBINARY(40), C28 VARChar(40))"

            result = ibm_db.exec_immediate(conn, create)

            if(not serverinfo.DBMS_NAME.startswith("DB2/")):
                insert = "insert into TESTTYPES values(?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)"
            else:
                insert = "insert into TESTTYPES values(?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)"
            stmt = ibm_db.prepare(conn,insert)

            if(not serverinfo.DBMS_NAME.startswith("DSN")):
                rc = ibm_db.set_option(stmt, {ibm_db.SQL_ATTR_QUERY_TIMEOUT : 10}, 0)

            try:
                if(not serverinfo.DBMS_NAME.startswith("DB2/")):
                    ibm_db.bind_param(stmt, 1,  870000, 				ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 2,  date(1982, 2, 12), 		ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 3,  Decimal('8723'), 		ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 4,  Decimal('8723'), 		ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 5,  Decimal('8723'), 		ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 6,  8723.45, 				ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 7,  8723, 					ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 8, 87, 					    ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 9, b'To Test BINARY', 		ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 10, b'To Test Blob', 		ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 11, b'To Test Char', 		ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 12, b'To Test Clob', 		ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 13, b'1981-07-08 10:42:34.000010', ibm_db.SQL_PARAM_INPUT)	#String Timestamp
                    ibm_db.bind_param(stmt, 14, b'To Test VARChar', 	ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 15, time(12, 35, 45), 		ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 16, datetime(2017, 11, 28, 23, 55, 59, 342380), ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 17, 'To Test UniBINARY', 	ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 18, 'To Test UniBlob', 		ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 19, 'To Test UniChar', 		ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 20, 'To Test UniClob', 		ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 21, '1981-07-08 10:42:34.000010', ibm_db.SQL_PARAM_INPUT)	#Unicode Timestamp
                    ibm_db.bind_param(stmt, 22, 'To Test UniVARBINARY', ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 23, 'To Test UniVARChar', 	ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 24, '1981-07-08 10:42:34.000010 -05:45', ibm_db.SQL_PARAM_INPUT)
                else:
                    ibm_db.bind_param(stmt, 1,  870000, 				ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 2,  True, 					ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 3,  False, 					ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 4,  date(1982, 2, 12), 		ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 5,  Decimal('8723'), 		ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 6,  Decimal('8723'), 		ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 7,  Decimal('8723'), 		ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 8,  8723.45, 				ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 9,  8723, 					ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 10, 87, 					ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 11, b'To Test BINARY', 		ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 12, b'To Test Blob', 		ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 13, b'To Test Char', 		ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 14, b'To Test Clob', 		ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 15, b'To Test DBClob', 		ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 16, b'1981-07-08 10:42:34.000010', ibm_db.SQL_PARAM_INPUT)	#String Timestamp
                    ibm_db.bind_param(stmt, 17, b'To Test VARBINARY', 	ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 18, b'To Test VARChar', 	ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 19, time(12, 35, 45), 		ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 20, datetime(2017, 11, 28, 23, 55, 59, 342380), ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 21, 'To Test UniBINARY', 	ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 22, 'To Test UniBlob', 		ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 23, 'To Test UniChar', 		ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 24, 'To Test UniClob', 		ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 25, 'To Test UniDBClob', 	ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 26, '1981-07-08 10:42:34.000010', ibm_db.SQL_PARAM_INPUT)	#Unicode Timestamp
                    ibm_db.bind_param(stmt, 27, 'To Test UniVARBINARY', ibm_db.SQL_PARAM_INPUT)
                    ibm_db.bind_param(stmt, 28, 'To Test UniVARChar', 	ibm_db.SQL_PARAM_INPUT)
                error = ibm_db.execute(stmt)
            except:
                excp = sys.exc_info()
                # slot 1 contains error message
                print(excp[1])

            # Select the result from the table and
            query = "select * from TESTTYPES"
            exe = ibm_db.exec_immediate(conn,query)

            row = ibm_db.fetch_tuple(exe)
            rcount = 1
            while row:
                count = 1
                for col in row:
                    print("Column:" + str(count) + ' ' +  str(col))
                    count += 1
                print("-------------------")
                row = ibm_db.fetch_tuple(exe)

            ibm_db.close(conn)
        else:
            print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#Column:1 870000
#Column:2 True
#Column:3 False
#Column:4 1982-02-12
#Column:5 8723
#Column:6 8723
#Column:7 8723.00
#Column:8 8723.45
#Column:9 8723.00
#Column:10 87
#Column:11 b'To Test BINARY\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00'
#Column:12 b'To Test Blob'
#Column:13 To Test Char                  
#Column:14 To Test Clob
#Column:15 To Test DBClob
#Column:16 1981-07-08 10:42:34.000010
#Column:17 b'To Test VARBINARY'
#Column:18 To Test VARChar
#Column:19 12:35:45
#Column:20 2017-11-28 23:55:59.342380
#Column:21 b'T\x00o\x00 \x00T\x00e\x00s\x00t\x00 \x00U\x00n\x00i\x00B\x00I\x00N\x00A\x00R\x00Y\x00\x00\x00\x00\x00\x00\x00'
#Column:22 b'T\x00o\x00 \x00T\x00e\x00s\x00t\x00 \x00U\x00n\x00i\x00B\x00l\x00o\x00b\x00'
#Column:23 To Test UniChar                         
#Column:24 To Test UniClob
#Column:25 To Test UniDBClob
#Column:26 1981-07-08 10:42:34.000010
#Column:27 b'T\x00o\x00 \x00T\x00e\x00s\x00t\x00 \x00U\x00n\x00i\x00V\x00A\x00R\x00B\x00I\x00N\x00A\x00R\x00Y\x00'
#Column:28 To Test UniVARChar
#-------------------
#__ZOS_EXPECTED__
#Column:1 870000
#Column:2 1982-02-12
#Column:3 8723
#Column:4 8723
#Column:5 8723.00
#Column:6 8723.45
#Column:7 8723.00
#Column:8 87
#Column:9 b'To Test BINARY\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00'
#Column:10 b'To Test Blob'
#Column:11 To Test Char                  
#Column:12 To Test Clob
#Column:13 1981-07-08 10:42:34.000010
#Column:14 To Test VARChar
#Column:15 12:35:45
#Column:16 2017-11-28 23:55:59.342380
#Column:17 b'T\x00o\x00 \x00T\x00e\x00s\x00t\x00 \x00U\x00n\x00i\x00B\x00I\x00N\x00A\x00R\x00Y\x00\x00\x00\x00\x00\x00\x00'
#Column:18 b'T\x00o\x00 \x00T\x00e\x00s\x00t\x00 \x00U\x00n\x00i\x00B\x00l\x00o\x00b\x00'
#Column:19 To Test UniChar                         
#Column:20 To Test UniClob
#Column:21 1981-07-08 10:42:34.000010
#Column:22 b'T\x00o\x00 \x00T\x00e\x00s\x00t\x00 \x00U\x00n\x00i\x00V\x00A\x00R\x00B\x00I\x00N\x00A\x00R\x00Y\x00'
#Column:23 To Test UniVARChar
#Column:24 1981-07-08-10.42.34.000010000000 -05:45
#-------------------
#__SYSTEMI_EXPECTED__
#Boolean is not supported
#__IDS_EXPECTED__
#Boolean is not supported



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#
# NOTE: IDS does not support XML as a native datatype (test is invalid for IDS)

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_195_InsertRetrieveXMLData_01(self):
        obj = IbmDbTestFunctions()
        obj.assert_expectf(self.run_test_195)

    def run_test_195(self):
        conn = ibm_db.connect(config.database, config.user, config.password)
        server = ibm_db.server_info( conn )

        if ((server.DBMS_NAME[0:3] != 'IDS') and (server.DBMS_NAME[0:2] != "AS")):
            drop = 'DROP TABLE test_195'
            try:
                result = ibm_db.exec_immediate(conn, drop)
            except:
                pass
            create = 'CREATE TABLE test_195 (id INTEGER, data XML)'
            result = ibm_db.exec_immediate(conn, create)

            insert = "INSERT INTO test_195 values (0, '<TEST><def><xml/></def></TEST>')"

            ibm_db.exec_immediate(conn, insert)

            sql =  "SELECT data FROM test_195"
            stmt = ibm_db.prepare(conn, sql)
            ibm_db.execute(stmt)
            result = ibm_db.fetch_assoc(stmt)
            while( result ):
                print("Output:", result)
                result = ibm_db.fetch_assoc(stmt)
            ibm_db.close(conn)
        else:
            print("Native XML datatype is not supported.")

#__END__
#__LUW_EXPECTED__
#Output:%s<TEST><def><xml/></def></TEST>
#__ZOS_EXPECTED__
#Output:%s<TEST><def><xml/></def></TEST>
#__SYSTEMI_EXPECTED__
#Native XML datatype is not supported.
#__IDS_EXPECTED__
#Native XML datatype is not supported.



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_120_FieldName(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_120)

    def run_test_120(self):
        conn = ibm_db.connect(config.database, config.user, config.password)
        server = ibm_db.server_info( conn )

        if conn:
            stmt = ibm_db.exec_immediate(conn, "SELECT * FROM animals")

            name1 = ibm_db.field_name(stmt, 1)
            name2 = ibm_db.field_name(stmt, 2)
            name3 = ibm_db.field_name(stmt, 3)
            name4 = ibm_db.field_name(stmt, 4)
            name6 = ibm_db.field_name(stmt, 8)
            name7 = ibm_db.field_name(stmt, 0)

            if (server.DBMS_NAME[0:3] == 'IDS'):
                name5 = ibm_db.field_name(stmt, "id")
                name8 = ibm_db.field_name(stmt, "WEIGHT")
            else:
                name5 = ibm_db.field_name(stmt, "ID")
                name8 = ibm_db.field_name(stmt, "weight")

            print("string(%d) \"%s\"" % (len(name1), name1))
            print("string(%d) \"%s\"" % (len(name2), name2))
            print("string(%d) \"%s\"" % (len(name3), name3))
            print("%s" % name4)

            print("string(%d) \"%s\"" % (len(name5), name5))
            print("%s" % name6)
            print("string(%d) \"%s\"" % (len(name7), name7))
            print("%s" % name8)
        else:
            print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#string(5) "BREED"
#string(4) "NAME"
#string(6) "WEIGHT"
#False
#string(2) "ID"
#False
#string(2) "ID"
#False
#__ZOS_EXPECTED__
#string(5) "BREED"
#string(4) "NAME"
#string(6) "WEIGHT"
#False
#string(2) "ID"
#False
#string(2) "ID"
#False
#__SYSTEMI_EXPECTED__
#string(5) "BREED"
#string(4) "NAME"
#string(6) "WEIGHT"
#False
#string(2) "ID"
#False
#string(2) "ID"
#False
#__IDS_EXPECTED__
#string(5) "breed"
#string(4) "name"
#string(6) "weight"
#False
#string(2) "id"
#False
#string(2) "id"
#False



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2016
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):
    def test_warn(self):
        obj = IbmDbTestFunctions()
        obj.assert_expectf(self.run_test_warn)

    def run_test_warn(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        # Get the server type
        serverinfo = ibm_db.server_info( conn )

        if conn:

            drop = "DROP TABLE WITH_CLOB"
            try:
                result = ibm_db.exec_immediate(conn,drop)
            except:
                pass

            # Create the table with_clob

            if (serverinfo.DBMS_NAME[0:3] != 'IDS'):
                create = "CREATE TABLE WITH_CLOB (id SMALLINT NOT NULL, clob_col CLOB(1k))"
            else:
                create = "CREATE TABLE WITH_CLOB (id SMALLINT NOT NULL, clob_col CLOB(smart))"
            result = ibm_db.exec_immediate(conn, create)

            # Select the result from the table. This is just to verify we get appropriate warning using
            # ibm_db.stmt_warn() API

            query = 'SELECT * FROM WITH_CLOB'
            if (serverinfo.DBMS_NAME[0:3] != 'IDS'):
                stmt = ibm_db.prepare(conn, query, {ibm_db.SQL_ATTR_CURSOR_TYPE: ibm_db.SQL_CURSOR_KEYSET_DRIVEN})
            else:
                stmt = ibm_db.prepare(conn, query)

            ibm_db.execute(stmt)
            data = ibm_db.fetch_both( stmt )
            if data:
                print("Success")
            else:
                print("No Data")
                print(ibm_db.stmt_warn(stmt))
            ibm_db.close(conn)
        else:
            print ("Connection failed.")

#__END__
#__LUW_EXPECTED__
#No Data[IBM][CLI Driver][DB2/%s] SQL0100W  No row was found for FETCH, UPDATE or DELETE; or the result of a query is an empty table.  SQLSTATE=02000 SQLCODE=100
#__ZOS_EXPECTED__
#No Data[IBM][CLI Driver][DB2]
# SQL0100W  No row was found for FETCH, UPDATE or DELETE; or the result of a query is an empty table.  SQLSTATE=02000 SQLCODE=100
#__SYSTEMI_EXPECTED__
#No Data
#__IDS_EXPECTED__
#No Data
#[IBM][CLI Driver][IDS/%s] SQL0100W  No row was found for FETCH, UPDATE or DELETE; or the result of a query is an empty table.  SQLSTATE=02000 SQLCODE=100
#__ZOS_ODBC_EXPECTED__
#No Data












#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_147_PrepareWithWrongType(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_147)

    def run_test_147(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        if conn:
            ibm_db.autocommit(conn, ibm_db.SQL_AUTOCOMMIT_OFF)

            stmt = ibm_db.prepare(conn, "INSERT INTO animals (id, breed, name) VALUES (?, ?, ?)")

            id = "\"999\""
            breed = None
            name = 'PythonDS'
            try:
                ibm_db.bind_param(stmt, 1, id)
                ibm_db.bind_param(stmt, 2, breed)
                ibm_db.bind_param(stmt, 3, name)

                error = ibm_db.execute(stmt)
                print("Should not make it this far")
            except:
                excp = sys.exc_info()
                # slot 1 contains error message
                print(excp[1])
            finally:
                ibm_db.close(conn)
        else:
            print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#Statement Execute Failed: [IBM][CLI Driver] CLI0112E  Error in assignment. SQLSTATE=22005 SQLCODE=-99999
#__ZOS_EXPECTED__
#Statement Execute Failed: [IBM][CLI Driver] CLI0112E  Error in assignment. SQLSTATE=22005 SQLCODE=-99999
#__SYSTEMI_EXPECTED__
#Statement Execute Failed: [IBM][CLI Driver] CLI0112E  Error in assignment. SQLSTATE=22005 SQLCODE=-99999
#__IDS_EXPECTED__
#Statement Execute Failed: [IBM][CLI Driver] CLI0112E  Error in assignment. SQLSTATE=22005 SQLCODE=-99999
#__ZOS_ODBC_EXPECTED__
#Statement Execute Failed: {DB2 FOR OS/390}{ODBC DRIVER}  SQLSTATE=22005  ERRLOC=4:3:2 SQLCODE=-99999



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_213_FieldDisplaySize_04(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_213)

    def run_test_213(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        result = ibm_db.exec_immediate(conn, "select * from sales")

        i = "sales_person"

        print("%s size %d\n" % (i, (ibm_db.field_display_size(result,i) or 0)))

        i = "REGION"

        print("%s size %d\n" % (i, (ibm_db.field_display_size(result,i) or 0)))

        i = "REgion"

        print("%s size %d\n" % (i, (ibm_db.field_display_size(result,i) or 0)))

        i = "HELMUT"

        print("%s size %d\n" % (i, (ibm_db.field_display_size(result,i) or 0)))

        t = ibm_db.field_display_size(result,"")

        print(t)

        t = ibm_db.field_display_size(result,"HELMUT")

        print(t)

        t = ibm_db.field_display_size(result,"Region")

        print(t)

        t = ibm_db.field_display_size(result,"SALES_DATE")

        print(t)

#__END__
#__LUW_EXPECTED__
#sales_person size 0
#REGION size 15
#REgion size 0
#HELMUT size 0
#False
#False
#False
#10
#__ZOS_EXPECTED__
#sales_person size 0
#REGION size 15
#REgion size 0
#HELMUT size 0
#False
#False
#False
#10
#__SYSTEMI_EXPECTED__
#sales_person size 0
#REGION size 15
#REgion size 0
#HELMUT size 0
#False
#False
#False
#10
#__IDS_EXPECTED__
#sales_person size 15
#REGION size 0
#REgion size 0
#HELMUT size 0
#False
#False
#False
#False



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_102_NumFieldsSelect_01(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_102)

    def run_test_102(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        if (not conn):
            print(ibm_db.conn_errormsg())

        server = ibm_db.server_info( conn )
        if ((server.DBMS_NAME[0:2] != "AS") and (server.DBMS_NAME != "DB2") and (server.DBMS_NAME[0:3] != "IDS") and (server.DBMS_NAME[0:3] != "DSN")):
            result = ibm_db.exec_immediate(conn, "VALUES(1)")
            #throw :unsupported unless result
            if (not result):
                raise Exception('Unsupported')
            print(ibm_db.num_fields(result))
        else:
            print('1')
        ibm_db.close(conn)

#__END__
#__LUW_EXPECTED__
#1
#__ZOS_EXPECTED__
#1
#__SYSTEMI_EXPECTED__
#1
#__IDS_EXPECTED__
#1
